"use client";
import { useEffect, useRef, useState } from "react";
import { imgError } from "@/utils";
import { Switch } from "@/components/ui/switch";
import {
  FaCamera,
  FaUserCircle,
  FaChevronLeft,
  FaChevronRight,
  FaEnvelope,
} from "react-icons/fa";
import { AiOutlineUsergroupAdd } from "react-icons/ai";
import { Navigation } from "swiper/modules";
import profileImages from "@/assets/json/profileImages";
import { BsArrowRightShort, BsArrowLeftShort } from "react-icons/bs";
import {
  register,
  updateProfileApi,
  updateProfileDataApi,
  updateUserDataInfo,
} from "@/store/reducers/userSlice";
import toast from "react-hot-toast";
import { useRouter } from "next/navigation";
import { useSelector } from "react-redux";
import { t } from "@/utils";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css/effect-fade";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import userImg from "../../assets/images/user.svg";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";
import { Input } from "@/components/ui/input";
import { Button } from "@/components/ui/button";
import {
  Carousel,
  CarouselContent,
  CarouselItem,
} from "@/components/ui/carousel";
const NewUser = ({ profile, setProfile }) => {
  const [swiper, setSwiper] = useState();

  const navigationPrevRef = useRef(null);

  const [showReferCode, setShowReferCode] = useState(false);

  const [api, setApi] = useState();

  const userData = useSelector((state) => state.User);

  const navigationNextRef = useRef(null);

  const loginType = userData?.data?.type;

  const router = useRouter();

  // dummy profile update
  const dummyProfileImage = (e) => {
    e.preventDefault();
    const fileName = e.target.getAttribute("data-file");
    const url = `${window.location.origin}/images/profileimages/${fileName}`;

    fetch(url).then(async (response) => {
      const contentType = response.headers.get("content-type");
      const blob = await response.blob();
      const file = new File([blob], fileName, { contentType });
      // access file here
      updateProfileApi(
        file,
        (success) => {
          toast.success(t("successfully_updated"));
        },
        (error) => {
          toast.error(error);
        }
      );
    });
  };

  // new user form submit
  const formSubmit = (e) => {
    e.preventDefault();
    let firebase_id = profile.uid;
    let email = profile.email ? profile.email : null;
    let phone = profile.phoneNumber ? profile.phoneNumber : null;
    let image_url = profile.photoURL ? profile.photoURL : null;
    let name = profile.name;
    let fcm_id = null;
    let friends_code = profile.friends_code;
    register(
      firebase_id,
      loginType,
      name,
      email,
      image_url,
      phone,
      fcm_id,
      friends_code,
      (success) => {
        router.push("/quiz-play");
      },
      (error) => {
        if (error === "126") {
          toast.error(t("ac_deactive"));
        } else {
          toast.error(`${t("please ")}${t("try_again")}`);
          console.log("formSubmit", error);
        }
      }
    );
    if (profile.image) {
      updateProfileApi(profile.image);
    }
    if (loginType == "mobile") {
      updateProfileDataApi(
        profile.email,
        profile.name,
        profile.mobile,
        (success) => {
          updateUserDataInfo({ email: profile.email });
        },
        (error) => {
          console.log(error);
          toast.error(error);
        }
      );
    }
  };

  // handle image change
  const handleImageChange = (e) => {
    e.preventDefault();
    updateProfileApi(e.target.files[0]);
  };

  // set input field data
  const handleChange = (event) => {
    const field_name = event.target.name;
    const field_value = event.target.value;
    setProfile((values) => ({ ...values, [field_name]: field_value }));
  };

  // refer code
  const changeReferCodeCheckbox = () => {
    console.log(1111);

    let state = !showReferCode;
    setShowReferCode(state);
  };

  const swiperOption = {
    loop: false,
    speed: 750,
    spaceBetween: 20,
    slidesPerView: 4,
    breakpoints: {
      0: {
        slidesPerView: 3.5,
      },
      1200: {
        slidesPerView: 4,
      },
    },
    autoplay: false,
  };

  // useEffect(() => {
  //   if (swiper) {
  //     swiper.params.navigation.prevEl = navigationPrevRef.current
  //     swiper.params.navigation.nextEl = navigationNextRef.current
  //     swiper.navigation.init()
  //     swiper.navigation.update()
  //   }
  // }, [swiper])

  useEffect(() => {
    if (!api) {
      return;
    }

    api.on("select", () => {
      console.log(api);
    });
  }, [api]);

  const onNext = () => {
    api.scrollNext();
  };

  const onPre = () => {
    api.scrollPrev();
  };
  return (
    <>
      <div className="container mt-5  mb-14">
        <div className="max-w-[600px] w-full m-auto mt-5 mb-40">
          <div className="morphisam">
            <form onSubmit={formSubmit}>
              <div className="">
                <div className="">
                  <div className="flex-center p-5 flex-col">
                    <h2 className="headline">{t("user_settings")}</h2>
                    <p className="text-center">{t("upload_your_photo")}</p>
                    <div className="h-[120px] w-[120px] flex-center rounded-full border-2 border-dashed border-text-color relative p-[5px] mt-[30px]">
                      {userData?.data && userData?.data?.profile ? (
                        <img
                          className="max-w-full max-h-full rounded-full mx-auto w-[100px] h-[100px] overflow-hidden"
                          src={userData?.data?.profile}
                          alt="profile"
                          id="user_profile"
                          onError={imgError}
                        />
                      ) : (
                        <ThemeSvg
                          src={userImg.src}
                          className="max-w-full max-h-full rounded-full mx-auto w-[100px] h-[100px] overflow-hidden"
                          width="100%"
                          height="100%"
                          alt="User"
                          colorMap={{
                            "#e13975": "var(--primary-color)",
                            "#6d1d50": "var(--secondary-color)",
                            "#f7ccdd": "var(--primary-light)",
                            "url(#linear-gradient)": "var(--primary-color)",
                            "linear-gradient": "var(--primary-color)",
                          }}
                        />
                      )}
                      <div className="block">
                        <input
                          type="file"
                          name="profile"
                          id="file"
                          onChange={handleImageChange}
                          className="h-0 w-0 "
                        />
                        <label
                          className="cursor-pointer outline-none transition-all duration-300 align-middle m-0 absolute bottom-[20px] right-[-6px] bg-[#00bf7a] text-white h-[35px] w-[35px] rounded-full border border-white text-[0.75rem] flex justify-center items-center"
                          htmlFor="file"
                        >
                          {" "}
                          <em>
                            <FaCamera />
                          </em>
                        </label>
                        <input
                          type="text"
                          className="form-control"
                          placeholder="Upload File"
                          id="file1"
                          name="myfile"
                          disabled
                          hidden
                        />
                      </div>
                    </div>

                    {/* dummy image slider */}
                    <div className="w-[85%]  relative flex-center flex-wrap my-5">
                      <div className="absolute left-[-43px] " onClick={onPre}>
                        <span>
                          <FaChevronLeft size={25} className="text-[#090029]" />
                        </span>
                      </div>
                      <Carousel
                        setApi={setApi}
                        opts={{
                          align: "start",
                        }}
                        className="w-full"
                      >
                        <CarouselContent>
                          {profileImages &&
                            profileImages.map((elem, index) => (
                              <CarouselItem
                                key={index}
                                className="max-399:basis-1/3 sm:basis-1/6 basis-1/5"
                              >
                                <div className="p-1 image_section">
                                  <div className="!bg-transparent rounded-lg  flex items-center justify-center aspect-square">
                                    <img
                                      src={elem?.img}
                                      alt="profile"
                                      className="cursor-pointer w-full h-full object-cover rounded-lg"
                                      onClick={(e) => dummyProfileImage(e)}
                                      data-file={elem?.img.split("/").pop()}
                                    />
                                  </div>
                                </div>
                              </CarouselItem>
                            ))}
                        </CarouselContent>
                      </Carousel>
                      <div className="absolute right-[-37px]" onClick={onNext}>
                        <span>
                          <FaChevronRight
                            size={25}
                            className="text-[#090029]"
                          />
                        </span>
                      </div>
                    </div>

                    <div className="py-4 flex flex-col w-full">
                      <div className="relative mb-5">
                        <label htmlFor="">
                          <Input
                            type="text"
                            name="name"
                            id="fullName"
                            placeholder={t("enter_name")}
                            defaultValue={profile.name}
                            onChange={handleChange}
                            required
                            className="w-full rounded-[8px] bg-white h-16 pl-14 text-[#212529] border border-gray-300"
                          />
                          <span className="absolute top-0 left-0 bottom-0 flex items-center justify-center text-[#767272] font-semibold p-[5px_15px] h-16 text-[20px] rounded-tl-[5px] rounded-bl-[5px] overflow-hidden">
                            <FaUserCircle />
                          </span>
                        </label>
                      </div>

                      {loginType == "mobile" && (
                        <div className="relative">
                          <label htmlFor="">
                            <Input
                              type="email"
                              name="email"
                              id="email"
                              placeholder={t("enter_email")}
                              defaultValue={profile.email}
                              onChange={handleChange}
                              className="w-full rounded-[8px] bg-white h-16 pl-14 text-[#212529] border border-gray-300"
                            />
                            <span className="absolute top-0 left-0 bottom-0 flex items-center justify-center text-[#767272] font-semibold p-[5px_15px] h-16 text-[20px] rounded-tl-[5px] rounded-bl-[5px] overflow-hidden">
                              <FaEnvelope />
                            </span>
                          </label>
                        </div>
                      )}

                      <div className="mt-5 flex justify-between">
                        <p>{t("do_you_have_refer_code")}</p>
                        <Switch
                          className="!bg-primary-color"
                          // checked={showReferCode}
                          onCheckedChange={changeReferCodeCheckbox}
                        />
                      </div>

                      {showReferCode ? (
                        <label htmlFor="w-full !relative flex justify-center items-center overflow-hidden text-[#888888]">
                          <div className="relative">
                            <Input
                              type="text"
                              name="friends_code"
                              id="friends_code"
                              placeholder={t("Refer Code")}
                              defaultValue={profile.friends_code}
                              onChange={handleChange}
                              required
                              className="w-full rounded-[8px] bg-white h-16 pl-14 text-[#212529] border border-gray-300"
                            />
                            <span className="absolute top-0 left-0 bottom-0 flex items-center justify-start text-[#767272] font-semibold p-[0px_15px] h-[63px] text-[20px] rounded-tl-[5px] rounded-bl-[5px] overflow-hidden ">
                              <AiOutlineUsergroupAdd />
                            </span>
                          </div>
                        </label>
                      ) : (
                        ""
                      )}
                      <Button
                        className="capitalize"
                        type="submit"
                        value="submit"
                        name="submit"
                        id="mc-embedded-subscribe"
                        variant="login"
                        size="login"
                      >
                        {t("submit")}
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </form>
          </div>
        </div>
      </div>
    </>
  );
};

export default NewUser;
