"use client";
import { Swiper, SwiperSlide } from "swiper/react";
import { t } from "@/utils";
import { withTranslation } from "react-i18next";
import Skeleton from "react-loading-skeleton";
import Link from "next/link";
import { Button } from "@/components/ui/button";

import "swiper/css/effect-fade";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";

// import required modules
import { EffectFade, Navigation, Pagination, Autoplay } from "swiper/modules";
import { truncate } from "@/utils";

const IntroSlider = ({ homeSettings, isLoading }) => {
  return (
    <div className="intro-slider-wrap bg-[#F1F0F3] -mt-[112px] pt-[100px] relative max-[479px]:flex max-[479px]:justify-center max-[479px]:items-center max-[479px]:bg-transparent section">
      <div className="container mb-14">
        <Swiper
          // loop={true}
          spaceBetween={30}
          effect={"fade"}
          speed={500}
          autoplay={true}
          navigation={false}
          pagination={{
            clickable: true,
            bulletClass: "swiper-pagination-bullet custom-bullet",
            bulletActiveClass:
              "swiper-pagination-bullet-active custom-bullet-active",
          }}
          fadeEffect={{
            crossFade: true,
          }}
          modules={[EffectFade, Navigation, Pagination, Autoplay]}
          className="mySwiper intro-slider"
        >
          {isLoading ? (
            // Show skeleton loading when data is being fetched
            <div className="col-12 absolute top-[9%] w-[73%] left-0 right-0 mx-auto max-991:relative">
              <Skeleton height={20} count={22} />
            </div>
          ) : homeSettings && homeSettings?.sliderData?.length > 0 ? (
            homeSettings?.sliderData.map((data, key) => (
              <SwiperSlide key={key}>
                <div className="flex items-center relative text-left mx-auto my-[40px] sm:text-center">
                  <div className="container relative px-0">
                    <div className="flex flex-col lg:flex-row items-center gap-5 lg:gap-3">
                      <div className="w-full lg:w-1/2 mb-4 text-left">
                        <div className="text-xl sm:text-2xl font-medium break-words overflow-hidden text-ellipsis lg:line-clamp-2 line-clamp-none lg:justify-start justify-center items-center">
                          <h3 className="capitalize text-xl sm:text-3xl md:text-4xl lg:text-6xl sm:leading-tight font-bold break-words text-center lg:text-start">
                            {data && truncate(data?.title, 44)}
                          </h3>
                          <p className="overflow-hidden text-ellipsis line-clamp-2 text-base sm:text-[24px] font-medium text-gray-600 break-words my-2 md:my-4 text-center lg:text-start">
                            {data && data?.description ? (
                              data?.description
                            ) : (
                              <Skeleton />
                            )}
                          </p>
                        </div>
                        <div className="flex justify-center lg:justify-normal mt-4 md:mt-6">
                          <Link
                            href={"/quiz-play"}
                            className="btn btn-primary slider1__btn me-2 "
                          >
                            <Button variant="login" className="w-auto py-3 md:py-6">
                              {t("lets_lay")}
                            </Button>
                          </Link>
                          <Link
                            href={"/contact-us"}
                            className="btn slider1__btn2 text-white "
                          >
                            <Button
                              variant="login"
                              className="w-auto bg-secondary-color !py-3 md:!py-6 flex-center"
                            >
                              {t("contact_us")}
                            </Button>
                          </Link>
                        </div>
                      </div>
                      <div className="w-full lg:w-1/2">
                        <div className="bg-center bg-no-repeat w-full relative max-w-full max-h-full">
                          {data?.image ? (
                            <img
                              className="animate-updown w-full h-full max-h-[450px] object-contain"
                              src={data?.image}
                              alt="slider"
                            />
                          ) : (
                            <Skeleton height={400} count={5} />
                          )}
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </SwiperSlide>
            ))
          ) : null}
        </Swiper>
      </div>
    </div>
  );
};

export default withTranslation()(IntroSlider);
