"use client";
import React, { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { FaRegBell } from "react-icons/fa";
import { withTranslation, useTranslation } from "react-i18next";
import Swal from "sweetalert2";
import withReactContent from "sweetalert2-react-content";
import { useDispatch, useSelector } from "react-redux";
import { IoExitOutline } from "react-icons/io5";
import Link from "next/link";
import { useRouter } from "next/router";
import {
  appLanList,
  appLanListData,
  currentAppLan,
  currentAppLanguage,
  isRtl,
  languageJson,
  languageJsonFile,
  loadLanguages,
  rtlSupport,
  selectCurrentLanguage,
  selectLanguages,
  setCurrentLanguage,
} from "@/store/reducers/languageSlice";
import { sysConfigdata } from "@/store/reducers/settingsSlice";
import FirebaseData from "@/utils/Firebase";
import { imgError, isLogin } from "@/utils";
import { logout } from "@/store/reducers/userSlice";
import img6 from "../../../public/images/profileimages/6.svg";
import warningImg from "../../assets/images/logout.svg";
import noNotificationImg from "../../assets/images/notification.svg";
import {
  loadNotification,
  notifiationTotal,
  notificationData,
  updateTotal,
} from "@/store/reducers/notificationSlice";
import { signOut } from "firebase/auth";
import userImg from "../../assets/images/user.svg";
import {
  getsystemLanguageJson,
  getsystemLanguageListApi,
} from "@/store/actions/campaign";
import { t } from "@/utils";
import { updateI18nTranslations } from "@/utils/language";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import {
  NavigationMenu,
  NavigationMenuContent,
  NavigationMenuIndicator,
  NavigationMenuItem,
  NavigationMenuLink,
  NavigationMenuList,
  NavigationMenuTrigger,
  NavigationMenuViewport,
} from "@/components/ui/navigation-menu";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog";
import { Tooltip } from "react-tooltip";
import { capitalize } from "@/lib/utils";
import { IoIosArrowDown } from "react-icons/io";
import NotificationModal from "../Notifications/NotificationModal";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";

const MySwal = withReactContent(Swal);

const TopHeader = () => {
  const dispatch = useDispatch();

  const { auth } = FirebaseData();

  const router = useRouter();

  const { i18n } = useTranslation();

  const languages = useSelector(selectLanguages);

  const selectcurrentLanguage = useSelector(selectCurrentLanguage);

  // store data get

  const userData = useSelector((state) => state.User);

  const notification = useSelector(notificationData);

  const notificationtotal = useSelector(notifiationTotal);
  //console.log(notificationtotal);

  const systemconfig = useSelector(sysConfigdata);

  const languageJsondata = useSelector(languageJsonFile);

  const appLanguageList = useSelector(appLanList);

  const currAppLan = useSelector(currentAppLanguage);

  const isrtl = useSelector(rtlSupport);

  //notification
  const [notificationmodal, setNotificationModal] = useState(false);

  const [logoutModal, setLogoutModal] = useState(false);

  const [guestlogout, setGuestLogout] = useState(false);

  // App language change
  const appLanguageChange = async (name) => {
    dispatch(currentAppLan(name));
    getsystemLanguageJson({
      language: name,
      onSuccess: (response) => {
        dispatch(languageJson(response));
        dispatch(isRtl(response.rtl_support));
        updateI18nTranslations(response.data);
      },
    });
  };
  // language change
  const languageChange = async (name, code, id) => {
    setCurrentLanguage(name, code, id);
    // await i18n.changeLanguage(code)
  };

  // if APP language change and if it rtl supported then rtl else ltr
  useEffect(() => {
    if (isrtl && isrtl === "1") {
      document.documentElement.dir = "rtl";
    } else {
      document.documentElement.dir = "ltr";
    }
  }, [isrtl]);

  //api render
  useEffect(() => {
    if (router.pathname === "/" || router.pathname === "/quiz-play") {
      loadLanguages(
        "",
        (response) => {
          if (selectcurrentLanguage.code == null) {
            let index = response?.data?.filter((data) => {
              if (response?.data?.length == 1) {
                return { code: data.code, name: data.name, id: data.id };
              } else if (data.default_active == "1") {
                return { code: data.code, name: data.name, id: data.id };
              }
            });
            setCurrentLanguage(index[0].language, index[0].code, index[0].id);
          }
        },
        (error) => {
          if (error === "102") {
            setCurrentLanguage("English (US)", "en", "14");
          }
        }
      );
    }
  }, [router, selectcurrentLanguage]);

  const [offset, setOffset] = useState(0);
  const [limit, setLimit] = useState(10);

  useEffect(() => {
    if (isLogin()) {
      // console.log("Loading Notifications")
      if (router.pathname === "/" || router.pathname === "/quiz-play") {
        loadNotification({
          order: "DESC",
          offset: offset,
          limit: limit,
          onSuccess: (res) => {
            let response = res.total;
            dispatch(updateTotal(Number(response)));
          },
          onError: (error) => {
            if (error === "102") {
              dispatch(updateTotal(0));
            }
            console.log(error);
          },
        });
      }
    }
  }, [offset]);

  // sign out
  const handleSignout = () => {
    setLogoutModal(true);
  };

  const handleConfirmLogout = () => {
    logout();
    signOut(auth);
    router.push("/");
    setLogoutModal(false);
  };

  // check user data for username
  let userName = "";

  const checkUserData = (userData) => {
    if (userData?.data && userData?.data?.name != "") {
      return (userName = userData?.data?.name);
    } else if (userData?.data && userData?.data?.email != "") {
      return (userName = userData?.data?.email);
    } else {
      return (userName = userData?.data?.mobile);
    }
  };

  // guest logout
  const guestLogout = (e) => {
    e.preventDefault();
    setGuestLogout(true);
    router.push("/auth/login");
  };

  // profile image logout
  const profileGuest = (e) => {
    e.preventDefault();
    MySwal.fire({
      text: t("login_first"),
      icon: "warning",
      showCancelButton: true,
      cancelButtonText: t("cancel"),
      customClass: {
        confirmButton: "Swal-confirm-buttons",
        cancelButton: "Swal-cancel-buttons",
      },
      confirmButtonText: t("login"),
      allowOutsideClick: false,
    }).then((result) => {
      if (result.isConfirmed) {
        guestLogout(e);
      }
    });
  };

  // notification tooltip leave on mouse
  const handleMouseLeave = () => {
    const tooltipElement = document.querySelector(
      '[data-tooltip-id="custom-my-tooltip"]'
    );
    if (tooltipElement) {
      tooltipElement.removeAttribute("data-tooltip-content");
    }
  };

  // notification tooltip enter on mouse
  const handleMouserEnter = () => {
    console.log("enter");

    const tooltipElement = document.querySelector(
      '[data-tooltip-id="custom-my-tooltip"]'
    );
    if (tooltipElement) {
      tooltipElement.setAttribute(
        "data-tooltip-content",
        `${t("notifications")}`
      );
    }
  };

  useEffect(() => {
    const firstLoad = sessionStorage.getItem("firstLoad_App_Language");
    const manualRefresh = sessionStorage.getItem("manualRefresh_App_Language");
    const shouldFetchData = !firstLoad || manualRefresh === "true";

    if (shouldFetchData || languageJsondata == null) {
      let defaultLang = null;
      getsystemLanguageListApi({
        onSuccess: (response) => {
          response.data.filter((lan) => {
            if (lan.web_default == 1) {
              defaultLang = lan.name;
            }
          });
          sessionStorage.setItem("firstLoad_App_Language", "true");
          dispatch(appLanListData(response));
          if (currAppLan) {
            dispatch(currentAppLan(currAppLan));
          } else {
            dispatch(currentAppLan(defaultLang));
          }

          getsystemLanguageJson({
            language: currAppLan || defaultLang,
            onSuccess: (response) => {
              sessionStorage.setItem("lastFetch_App_language", "true");

              dispatch(languageJson(response));
              updateI18nTranslations(response.data);
            },
          });
        },
      });
    }
    sessionStorage.removeItem("manualRefresh_App_Language");
    sessionStorage.setItem("firstLoad_App_Language", "true");
  }, []);

  // Event listener to set manualRefresh flag when page is manually refreshed
  if (typeof window !== "undefined") {
    window.addEventListener("beforeunload", () => {
      sessionStorage.setItem("manualRefresh_App_Language", "true");
    });

    window.addEventListener("load", () => {
      // Check if this is a manual refresh by checking if lastFetch is set
      if (!sessionStorage.getItem("lastFetch_App_language")) {
        sessionStorage.setItem("manualRefresh_App_Language", "true");
      }
    });
  }

  const handleMoreNotifications = (e) => {
    e.preventDefault();
    setOffset((prevOffset) => prevOffset + limit);
    setLimit((prevLimit) => prevLimit + 10);
  };

  return (
    <React.Fragment>
      <div className=" bg-secondary-color text-white z-40 relative hidden xl:block">
        <div className="container ">
          <div className=" justify-between items-center grid grid-cols-1 md:grid-cols-2 gap-4">
            <div className="">
              {(router.pathname === "/" || router.pathname === "/quiz-play") &&
              !(
                appLanguageList &&
                appLanguageList.length === 1 &&
                languages &&
                languages.length === 1
              ) ? (
                <div className="flex ml-3">
                  {appLanguageList && appLanguageList.length !== 1 && (
                    <div className="flex-center [&>p]:mb-0 mr-2">
                      <p>{t("web")} :</p>
                      {/* <DropdownMenu>
                        <DropdownMenuTrigger asChild>
                          <Button
                            variant="language"
                            className=" flex items-center  mx-2"
                          >
                            {currAppLan ? capitalize(currAppLan) : t("language")} <IoIosArrowDown />
                          </Button>
                        </DropdownMenuTrigger>
                        <DropdownMenuContent className="bg-white rounded-[5px] w-24">
                          {appLanguageList &&
                            appLanguageList.map((data) => (
                              <DropdownMenuItem
                                key={data.name}
                                onClick={() =>
                                  appLanguageChange(data.name, data.title)
                                }
                              >
                                {data.title}
                              </DropdownMenuItem>
                            ))}
                        </DropdownMenuContent>
                      </DropdownMenu> */}
                      <NavigationMenu className="[&>:nth-child(2)]:left-2">
                        <NavigationMenuList>
                          <NavigationMenuItem>
                            <NavigationMenuTrigger className="!bg-primary-color flex items-center mx-2 !text-white ">
                              {currAppLan
                                ? capitalize(currAppLan)
                                : t("language")}
                            </NavigationMenuTrigger>
                            <NavigationMenuContent className="bg-white rounded-[5px]">
                              <ul className="w-max">
                                {appLanguageList &&
                                  appLanguageList.map((data) => (
                                    <li
                                      key={data.name}
                                      className="cursor-pointer w-full px-5 py-2 hover:bg-gray-100 capitalize"
                                      onClick={() =>
                                        appLanguageChange(data.name, data.title)
                                      }
                                    >
                                      {data.title}
                                    </li>
                                  ))}
                              </ul>
                            </NavigationMenuContent>
                          </NavigationMenuItem>
                        </NavigationMenuList>
                      </NavigationMenu>
                    </div>
                  )}
                  {systemconfig &&
                    systemconfig.language_mode === "1" &&
                    languages &&
                    languages.length > 1 && (
                      <div className="flex-center [&>p]:mb-0">
                        <p>{t("quiz_language")} :</p>
                        {/* <DropdownMenu>
                          <DropdownMenuTrigger asChild>
                            <Button
                              variant="language"
                              className=" flex items-center  mx-2"
                            >
                              {selectcurrentLanguage &&
                                selectcurrentLanguage.name
                                ? selectcurrentLanguage.name
                                : t("language")}
                            </Button>
                          </DropdownMenuTrigger>
                          <DropdownMenuContent className="bg-white rounded-[5px]">
                            {languages &&
                              languages.map((data) => (
                                <DropdownMenuItem
                                  key={data.id}
                                  onClick={() =>
                                    languageChange(
                                      data.language,
                                      data.code,
                                      data.id
                                    )
                                  }
                                >
                                  {data.language}
                                </DropdownMenuItem>
                              ))}
                          </DropdownMenuContent>
                        </DropdownMenu> */}
                        <NavigationMenu className="[&>:nth-child(2)]:left-2">
                          <NavigationMenuList>
                            <NavigationMenuItem>
                              <NavigationMenuTrigger className="!bg-primary-color flex items-center mx-2 !text-white">
                                {selectcurrentLanguage &&
                                selectcurrentLanguage.name
                                  ? selectcurrentLanguage.name
                                  : t("language")}
                              </NavigationMenuTrigger>
                              <NavigationMenuContent className="bg-white rounded-[5px]">
                                <ul className="w-max">
                                  {languages &&
                                    languages.map((data) => (
                                      <li
                                        key={data.id}
                                        className="cursor-pointer w-full px-3 py-2 hover:bg-gray-100 capitalize"
                                        onClick={() =>
                                          languageChange(
                                            data.language,
                                            data.code,
                                            data.id
                                          )
                                        }
                                      >
                                        {data.language}
                                      </li>
                                    ))}
                                </ul>
                              </NavigationMenuContent>
                            </NavigationMenuItem>
                          </NavigationMenuList>
                        </NavigationMenu>
                      </div>
                    )}
                </div>
              ) : (
                ""
              )}
            </div>

            <div className="">
              <div className="flex gap-3 justify-center items-center md:justify-end">
                <div className="rtl:mr-0 rtl:ml-2 flex float-right py-2.5 px-0 font-extrabold tracking-widest cursor-pointer">
                  {isLogin() && checkUserData(userData) ? (
                    <>
                      {/* <DropdownMenu>
                        <DropdownMenuTrigger asChild>
                          <a className="bg-primary-color text-white py-2.5 px-3 rounded font-normal hover:text-white active:text-white focus:text-white cursor-pointer">
                            {`${t("hello")} ${userName}`}
                          </a>
                        </DropdownMenuTrigger>
                        <DropdownMenuContent className="bg-white rounded-[5px] w-48">
                          <DropdownMenuItem
                            onClick={() => router.push("/profile")}
                          >
                            {t("profile")}
                          </DropdownMenuItem>
                          <DropdownMenuItem onClick={handleSignout}>
                            {t("logout")}
                          </DropdownMenuItem>
                        </DropdownMenuContent>
                      </DropdownMenu> */}
                      <NavigationMenu>
                        <NavigationMenuList>
                          <NavigationMenuItem>
                            <NavigationMenuTrigger className="!bg-primary-color text-base text-white py-2.5 px-3 rounded font-normal hover:text-white active:text-white focus:text-white cursor-pointer">
                              {`${t("hello")} ${userName}`}
                            </NavigationMenuTrigger>
                            <NavigationMenuContent>
                              <div className="flex flex-col gap-1 w-28">
                                <button
                                  onClick={() => router.push("/profile")}
                                  className="w-full text-left px-2 py-2 text-sm font-normal rounded-t-md hover:bg-gray-100 cursor-pointer"
                                >
                                  {t("profile")}
                                </button>

                                <button
                                  onClick={handleSignout}
                                  className="w-full text-left px-2 py-2 text-sm font-normal rounded-b-md hover:bg-gray-100 cursor-pointer"
                                >
                                  {t("logout")}
                                </button>
                              </div>
                            </NavigationMenuContent>
                          </NavigationMenuItem>
                        </NavigationMenuList>
                      </NavigationMenu>
                    </>
                  ) : (
                    <div>
                      {!guestlogout ? (
                        <div className="flex items-center rtl:gap-2.5">
                          <img
                            className="w-9 h-9 object-cover mr-2.5 rounded-full text-white bg-[var(--primary-color)] transition-all duration-500 ease-in border-transparent p-0.5"
                            onClick={(e) => profileGuest(e)}
                            src={img6.src}
                            alt="profile"
                          />
                          <button
                            id="dropdown-basic-button"
                            className="btn btn-primary py-[6px] px-4 font-medium tracking-normal"
                          >{`${t("hello_guest")}`}</button>
                          <button
                            className="btn bg-[var(--primary-color)] text-white transition-all duration-500 ease-in rounded-[8px] border-transparent flex items-center justify-center p-2.5 ms-2 rtl:rotate-180"
                            onClick={(e) => guestLogout(e)}
                          >
                            <IoExitOutline />
                          </button>
                        </div>
                      ) : (
                        <>
                          <span className="relative">
                            <Link
                              href="/auth/login"
                              className="hover:text-white mr-3 after:w-[2px] after:h-full  after:bg-white after:absolute after:right-[5px]"
                            >
                              {t("login")}
                            </Link>
                          </span>
                          <span>
                            <Link
                              href="/auth/sign-up"
                              className="font-semibold hover:text-white"
                            >
                              {t("sign_up")}
                            </Link>
                          </span>
                        </>
                      )}
                    </div>
                  )}
                </div>
                <div>
                  {isLogin() ? (
                    <Button
                      className="hover:bg-primary-color flex items-center text-white h-[45px] relative bg-primary-color transition ease-in duration-500 rounded-[8px] border-transparent"
                      onClick={() => setNotificationModal(true)}
                      onMouseEnter={handleMouserEnter}
                      onMouseLeave={handleMouseLeave}
                      data-tooltip-id="custom-my-tooltip"
                    >
                      <span className="absolute top-[2px] right-[6px] bg-[#212121] rounded-full w-[17px] text-[10px] text-white flex items-center justify-center">
                        {notification ? notification?.data?.length : "0"}
                      </span>
                      <FaRegBell />
                    </Button>
                  ) : (
                    ""
                  )}
                  {/* <Dialog
                    open={notificationmodal}
                    onOpenChange={setNotificationModal}
                  >
                    <DialogContent className="dialogContent ">
                      <DialogHeader>
                        <DialogTitle className='text-center text-[32px]'>{t("notification")}</DialogTitle>
                      </DialogHeader>

                      {notification?.data?.length ? (
                        <div className="max-h-[70vh] overflow-y-auto customScrollbar">
                          {notification.data.map((data, key) => (
                            <div
                              key={key}
                              className="flex items-center my-[20px] bg-white rounded-[16px] p-[12px]"
                            >
                              {data?.image ? (
                                <img
                                  className="object-contain w-[60px] h-[80px] rounded-[30px] mr-[20px]"
                                  src={data.image}
                                  alt="notification"
                                  id="image"
                                  onError={imgError}
                                />
                              ) : (
                                <ThemeSvg 
                                  src={userImg.src} 
                                  className="w-[60px] h-[80px] rounded-[30px] mr-[20px]"
                                  width="100%" 
                                  height="100%" 
                                  alt="User" 
                                  colorMap={{
                                    "#e13975": "var(--primary-color)",
                                    "#6d1d50": "var(--secondary-color)",
                                    "#f7ccdd": "var(--primary-light)"
                                  }}
                                />
                              )}
                              <div className="[dir='rtl']:mr-[10px] flex flex-col items-start gap-1">
                                <p className="text-[var(--text-color)] mb-0 font-bold text-[18px]">
                                  {data?.title}
                                </p>
                                <p className="text-start w-full text-[var(--text-color)] font-normal text-[16px] mb-0">
                                  {data?.message}
                                </p>
                                <span className="text-start text-gray-500 text-[14px] font-normal">
                                  {data?.date_sent}
                                </span>
                              </div>
                            </div>
                          ))}

                          {notificationtotal && notificationtotal > 10 && (
                            <div className="text-center mt-4">
                              <Button
                                onClick={handleMoreNotifications}
                                className="px-4 py-2 bg-primary-color text-white font-semibold rounded-lg "
                              >
                                {t("more")}
                              </Button>
                            </div>
                          )}
                        </div>
                      ) : (
                        <div className="w-[200px] block mx-auto sm:w-[260px]">
                          <img src={noNotificationImg.src} alt="" />
                        </div>
                      )}
                    </DialogContent>
                  </Dialog> */}
                  <NotificationModal
                    notificationmodal={notificationmodal}
                    setNotificationModal={setNotificationModal}
                  />
                </div>
                {/* <div className="darkmode ps-2">
                  <ThemeToggle />
                </div> */}
              </div>
            </div>
          </div>
        </div>
      </div>
      <Tooltip id="custom-my-tooltip" />

      <Dialog open={logoutModal} onOpenChange={setLogoutModal}>
        <DialogContent className="bg-white !rounded-[8px] p-[20px_24px] ">
          <DialogHeader>
            <DialogDescription>
              <div className="flex flex-col items-center justify-center gap-1 text-text-color font-sans">
                <span>
                  <img
                    className="w-[200px] sm:w-[190px]"
                    src={warningImg.src}
                    alt=""
                  />
                </span>
                <span className="text-[24px] font-semibold sm:text-[42px] sm:p-4 font-sans">
                  {t("logout")}
                </span>
                <span className="text-[16px] font-normal sm:text-[20px] sm:p-4">
                  {t("sure_logout")}
                </span>
              </div>

              <div className="flex justify-center items-center gap-5 mt-3">
                <span
                  className="bg-primary-color p-3 rounded-[16px] text-white text-base font-semibold cursor-pointer"
                  onClick={handleConfirmLogout}
                >
                  {t("yes_logout")}
                </span>
                <span
                  className="bg-white p-3 rounded-[16px] text-text-color text-base font-semibold cursor-pointer border-2 border-[#949191]"
                  onClick={() => setLogoutModal(false)}
                >
                  {t("keep_login")}
                </span>
              </div>
            </DialogDescription>
          </DialogHeader>
        </DialogContent>
      </Dialog>
    </React.Fragment>
  );
};
export default withTranslation()(TopHeader);
