import React from 'react'
import {
    Dialog,
    DialogContent,
    DialogDescription,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/components/ui/dialog";
import { useSelector } from 'react-redux';
import { notifiationTotal, notificationData } from '@/store/reducers/notificationSlice';
import noNotificationImg from "@/assets/images/notification.svg";
import Notification from './Notification';
import { t } from "@/utils/index";
import { Button } from '../ui/button';
import Link from 'next/link';

const NotificationModal = ({ notificationmodal, setNotificationModal }) => {
    const notifications = useSelector(notificationData);
    const notificationTotal = useSelector(notifiationTotal);
    // console.log("Notifications", notifications)
    // console.log("Total Notifications", notificationTotal);

    return (
        <Dialog
            open={notificationmodal}
            onOpenChange={setNotificationModal}
        >
            <DialogContent className="dialogContent max-h-[90vh] sm:max-h-[80vh] w-full sm:w-[500px] overflow-hidden">
                <DialogHeader>
                    <DialogTitle className="text-center text-lg sm:text-[28px]">{t("notifications")}</DialogTitle>
                </DialogHeader>

                <div className="overflow-y-auto overflow-x-hidden customScrollbar max-h-[65vh] md:px-4">
                    {notifications?.data?.length ? (
                        <div className="flex flex-col items-center justify-center gap-4">
                            {notifications.data.map((data, key) => (
                                // <div
                                //     key={key}
                                //     className="flex items-center my-[20px] bg-white rounded-[16px] p-[12px] first:mt-0 last:mb-0"
                                // >
                                //     <img
                                //         className="object-contain w-[60px] h-[80px] rounded-[30px] mr-[20px]"
                                //         src={data?.image || userImg.src}
                                //         alt="notification"
                                //         id="image"
                                //         onError={imgError}
                                //     />
                                //     <div className="[dir='rtl']:mr-[10px] flex flex-col items-start gap-1">
                                //         <p className="text-[var(--text-color)] mb-0 font-bold text-[18px]">
                                //             {data?.title}
                                //         </p>
                                //         <p className="text-start w-full text-[var(--text-color)] font-normal text-[16px] mb-0">
                                //             {data?.message}
                                //         </p>
                                //         <span className="text-start text-gray-500 text-[14px] font-normal">
                                //             {data?.date_sent}
                                //         </span>
                                //     </div>
                                // </div>
                                <Notification data={data} key={key} />
                            ))}
                            {notificationTotal > notifications?.data?.length && (
                                <div className="text-center mt-4">
                                    <Link
                                        href={"/notifications"}
                                        onClick={() => setNotificationModal(false)}
                                        // onClick={handleMoreNotifications}
                                        className="btnPrimary w-full"
                                    >
                                        {t("view_more")}
                                    </Link>
                                </div>
                            )}
                        </div>
                    ) : (
                        <div className="w-[200px] block mx-auto sm:w-[260px]">
                            <img src={noNotificationImg.src} alt="noNotificationsImg" />
                        </div>
                    )}
                </div>
            </DialogContent>
        </Dialog>
    )
}

export default NotificationModal