'use client'
import React, { useEffect, useState } from 'react'
import Breadcrumb from '../Common/Breadcrumb';
import dynamic from 'next/dynamic';
import { notificationData, notifiationTotal, loadNotification, updateTotal } from '@/store/reducers/notificationSlice';
import { useDispatch, useSelector } from 'react-redux';
import Notification from './Notification';
import noNotificationImg from "@/assets/images/notification.svg";
import { isLogin, t } from "@/utils/index";
import Link from 'next/link';
import { useRouter } from 'next/router';
import { Button } from '../ui/button';

const Layout = dynamic(() => import('@/components/Layout/Layout'), { ssr: false });

const NotificationsPage = () => {
    const router = useRouter()
    // const notifications = useSelector(notificationData)
    const totalNotifications = useSelector(notifiationTotal)
    const [limit, setLimit] = useState(10)
    const [offset, setOffset] = useState(0);
    const [notifications, setNotifications] = useState([]);
    const dispatch = useDispatch();
    useEffect(() => {
        if (isLogin()) {
            console.log("Loading Notifications")
            if (router.pathname === "/notifications") {
                loadNotification({
                    order: "DESC",
                    offset: offset,
                    limit: limit,
                    onSuccess: (res) => {
                        let response = res.total;
                        console.log(res)
                        setNotifications((prevData) => [...prevData, ...res.data]);
                        dispatch(updateTotal(response));
                    },
                    onError: (error) => {
                        if (error === "102") {
                            // dispatch(updateTotal(0));
                        }
                        console.log(error);
                    },
                });
            }
        }
    }, [offset]);

    const handleMoreNotifications = (e) => {
        e.preventDefault();
        setOffset((prevOffset) => prevOffset + limit);
        // setLimit((prevLimit) => prevLimit + 10);
    };
    console.log(notifications)
    return (
        <Layout>
            <Breadcrumb showBreadcrumb={true} title="Notifications" />
            <div className='container my-4 mx-auto h-full'>
                <div className='flex flex-col items-center justify-center morphisam gap-4'>
                    {notifications?.length ? (
                        <>
                            {notifications.map((data, key) => (
                                <Notification data={data} key={key} />
                            ))}

                            {notifications?.length < totalNotifications && (
                                <div className="text-center mt-4">
                                    <Button
                                        onClick={handleMoreNotifications}
                                        className="btnPrimary w-full"
                                    >
                                        {t("view_more")}
                                    </Button>
                                </div>
                            )}
                        </>
                    ) : (
                        <div className="w-[200px] block mx-auto sm:w-[260px]">
                            <img src={noNotificationImg.src} alt="noNotificationsImg" />
                        </div>
                    )}
                </div>
            </div>
        </Layout>
    )
}

export default NotificationsPage