import userSettingIcon from "@/assets/images/Usersetting.svg";
import bookmarkIcon from "@/assets/images/bookmark.svg";
import statisticsIcon from "@/assets/images/Statistics.svg";
import badgesIcon from "@/assets/images/badges.svg";
import leaderboardIcon from "@/assets/images/leaderboard.svg";
import walletIcon from "@/assets/images/Wallet.svg";
import inviteIcon from "@/assets/images/invitedfriend.svg";
import coinIcon from "@/assets/images/Coinhistory.svg";
import { t } from "@/utils";
import { useRouter } from "next/router";
import { sysConfigdata } from "@/store/reducers/settingsSlice";
import { useSelector } from "react-redux";
import { useState } from "react";
import FirebaseData from "@/utils/Firebase";
import { deleteuserAccountApi } from "@/store/actions/campaign";
import Swal from "sweetalert2";
import { logout } from "@/store/reducers/userSlice";
import warningImg from "@/assets/images/logout.svg";
import deleteAccImg from "@/assets/images/deleteAcc.svg";
import logouttabImg from "@/assets/images/logout-tab.svg";
import DeleteImg from "@/assets/images/Delete.svg";
import { signOut } from "firebase/auth";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
} from "@/components/ui/dialog";
import ThemeSvg from "@/components/ThemeSvg";

const LeftTabProfile = () => {
  const demoValue = process.env.NEXT_PUBLIC_DEMO === "true";

  const systemconfig = useSelector(sysConfigdata);

  const router = useRouter();

  const { auth } = FirebaseData();

  const [logoutModal, setLogoutModal] = useState(false);

  const [deleteAccModal, setDeleteAccModal] = useState(false);

  const path = router.pathname;

  // sign out
  const handleSignout = (e) => {
    e.preventDefault();
    setLogoutModal(true);
  };

  const handleConfirmLogout = () => {
    logout();
    signOut(auth);
    router.push("/");
    setLogoutModal(false);
  };

  const handleConfirmDeleteAcc = () => {
    deleteuserAccountApi({
      onSuccess: () => {
        Swal.fire(t("deleted"), t("Account Deleted Successfully!"), "success");
        // Current signed-in user to delete
        const firebaseUser = auth.currentUser;
        firebaseUser
          .delete()
          .then(() => {
            // User deleted.
          })
          .catch((error) => {
            console.log(error);
          });
        logout();
        signOut(auth);
        router.push("/");
        setDeleteAccModal(false);
      },
      onError: (error) => {
        if (demoValue) {
          Swal.fire(t("ops"), t("Not allowed in demo version"));
        } else {
          Swal.fire(t("ops"), t("please "), t("try_again"), "error");
        }
      },
    });
  };

  // delete user account
  const deleteAccountClick = (e) => {
    e.preventDefault();
    setDeleteAccModal(true);
  };

  return (
    <>
      <div className="flex max-1200:flex-row flex-col max-1200:gap-[6px] gap-[10px] px-[15px] py-0 max-1200:overflow-x-scroll max-1200:p-0 max-1200:py-2">
        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)] "
              : ""
          }`}
          onClick={() => router.push("/profile")}
        >
          <span>
            <img
              src={userSettingIcon.src}
              alt="profile"
              className="profileTabIcon"
            />
          </span>
          <span> {t("profile")}</span>
        </div>
        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/statistics"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/statistics")}
        >
          <span>
            <img src={statisticsIcon.src} alt="statistics" />
          </span>
          <span> {t("statistics")}</span>
        </div>

        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/bookmark"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/bookmark")}
        >
          <span>
            <img
              src={bookmarkIcon.src}
              alt="bookmark"
              className="bookmarkIcon"
            />{" "}
          </span>
          <span>{t("bookmark")}</span>
        </div>

        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/badges"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/badges")}
        >
          <span>
            <img src={badgesIcon.src} alt="badges" />
          </span>
          <span>{t("badges")}</span>
        </div>

        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/leaderboard"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/leaderboard")}
        >
          <span>
            <img src={leaderboardIcon.src} alt="leaderboard" />
          </span>
          <span>{t("leader_board")}</span>
        </div>

        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/coin-history"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/coin-history")}
        >
          <span>
            <img src={coinIcon.src} alt="coin-history" />
          </span>
          <span>{t("coin_history")}</span>
        </div>
        {systemconfig?.payment_mode === "1" ? (
          <div
            className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
              path === "/profile/wallet"
                ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
                : ""
            }`}
            onClick={() => router.push("/profile/wallet")}
          >
            <span>
              <img src={walletIcon.src} alt="wallet" />
            </span>
            <span> {t("wallet")}</span>
          </div>
        ) : null}
        <div
          className={`max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px] ${
            path === "/profile/invite-friends"
              ? "bg-primary-color text-white rounded-[16px] invert(1.5)  [&>span>img]:[filter:invert(1.5)_brightness(1.5)]"
              : ""
          }`}
          onClick={() => router.push("/profile/invite-friends")}
        >
          <span>
            <ThemeSvg
              src={inviteIcon.src}
              width={16}
              height={16}
              alt="invite-friends"
              colorMap={{ "#090029": "var(--primary-color)" }}
            />
          </span>
          <span> {t("invite_friends")} </span>
        </div>
        <div
          className="max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px]"
          onClick={(e) => handleSignout(e)}
        >
          <span>
            <img src={logouttabImg.src} alt="invite-friends" />
          </span>
          <span> {t("logout_account")} </span>
        </div>
        <div
          className="max-1200:py-2 max-1200:px-4 max-1200:gap-[12px] max-1200:[&>span]:w-max px-[24px] py-[18px] cursor-pointer max-1200:mx-0 -mx-[10px]  text-[16px] font-bold text-center flex justify-start items-center gap-[20px]"
          onClick={(e) => deleteAccountClick(e)}
        >
          <span>
            <img src={DeleteImg.src} alt="invite-friends" />
          </span>
          <span> {t("delete_account")} </span>
        </div>
      </div>
      <Dialog open={logoutModal} onOpenChange={setLogoutModal}>
        <DialogContent className="bg-white !rounded-[8px] p-[20px_24px] ">
          <DialogHeader>
            <DialogDescription>
              <div className="flex flex-col items-center justify-center gap-1 text-text-color font-sans">
                <span>
                  <img
                    className="w-[200px] sm:w-[190px]"
                    src={warningImg.src}
                    alt=""
                  />
                </span>
                <span className="text-[24px] font-semibold sm:text-[42px] sm:p-4 font-sans">
                  {t("logout")}
                </span>
                <span className="text-[16px] font-normal sm:text-[20px] sm:p-4">
                  {t("sure_logout")}
                </span>
              </div>

              <div className="flex justify-center items-center gap-5 mt-3">
                <span
                  className="bg-primary-color p-3 rounded-[16px] text-white text-base font-semibold cursor-pointer"
                  onClick={handleConfirmLogout}
                >
                  {t("yes_logout")}
                </span>
                <span
                  className="bg-white p-3 rounded-[16px] text-text-color text-base font-semibold cursor-pointer border-2 border-[#949191]"
                  onClick={() => setLogoutModal(false)}
                >
                  {t("keep_login")}
                </span>
              </div>
            </DialogDescription>
          </DialogHeader>
        </DialogContent>
      </Dialog>

      <Dialog open={deleteAccModal} onOpenChange={setDeleteAccModal}>
        <DialogContent className="bg-white !rounded-[8px] p-[20px_24px] ">
          <DialogHeader>
            <DialogDescription>
              <div className="flex flex-col items-center justify-center gap-1 text-text-color font-sans">
                <span>
                  <img
                    className="w-[200px] sm:w-[190px]"
                    src={deleteAccImg.src}
                    alt=""
                  />
                </span>
                <span className="text-[24px] font-semibold sm:text-[42px] sm:p-4 font-sans">
                  {t("delete_account")}
                </span>
                <span className="text-[16px] font-normal sm:text-[20px] sm:p-4">
                  {t("sure_delete_ac")}
                </span>
              </div>

              <div className="flex justify-center items-center gap-5 mt-3">
                <span
                  className="bg-primary-color p-3 rounded-[16px] text-white text-base font-semibold cursor-pointer"
                  onClick={handleConfirmDeleteAcc}
                >
                  {t("yes_delete")}
                </span>
                <span
                  className="bg-white p-3 rounded-[16px] text-text-color text-base font-semibold cursor-pointer border-2 border-[#949191]"
                  onClick={() => setDeleteAccModal(false)}
                >
                  {t("keep_account")}
                </span>
              </div>
            </DialogDescription>
          </DialogHeader>
        </DialogContent>
      </Dialog>
    </>
  );
};

export default LeftTabProfile;
