"use client";
import React, { useEffect, useCallback, useRef, useState } from "react";
import {
  FaChevronLeft,
  FaChevronRight,
  FaMobileAlt,
  FaPhoneAlt,
  FaPlus,
  FaRegUser,
} from "react-icons/fa";

import toast from "react-hot-toast";
import { withTranslation } from "react-i18next";
import {
  updateProfileApi,
  updateProfileDataApi,
  updateUserDataInfo,
} from "@/store/reducers/userSlice";
import { useSelector } from "react-redux";
import {
  UserCoinScoreApi,
  getusercoinsApi,
  setBadgesApi,
} from "@/store/actions/campaign";
import { imgError } from "@/utils";
import { badgesData, LoadNewBadgesData } from "@/store/reducers/badgesSlice";
import { HiOutlineMail } from "react-icons/hi";
import profileImages from "@/assets/json/profileImages";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css/effect-fade";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import Breadcrumb from "@/components/Common/Breadcrumb";
import userImg from "../../assets/images/user.svg";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";
// import required modules
import { Navigation } from "swiper/modules";
import { sysConfigdata } from "@/store/reducers/settingsSlice";
import { t } from "@/utils";
import LeftTabProfile from "./LeftTabProfile";
import {
  Carousel,
  CarouselContent,
  CarouselItem,
} from "@/components/ui/carousel";

const ProfileData = () => {
  const demoValue = process.env.NEXT_PUBLIC_DEMO === "true";

  const userData = useSelector((state) => state?.User);

  const systemconfig = useSelector(sysConfigdata);

  const [showBookMark, setShowBookMark] = useState(false);

  const [api, setApi] = useState();

  const [profile, setProfile] = useState({
    name: userData?.data?.name ? userData?.data?.name : "",
    email: userData?.data?.email ? userData?.data?.email : "",
    mobile: userData?.data?.mobile ? userData?.data?.mobile : "",
  });

  const Badges = useSelector(badgesData);

  const big_thingBadge = Badges?.data?.find(
    (badge) => badge?.type === "big_thing"
  );

  const eliteBadge = Badges?.data?.find((badge) => badge?.type === "elite");

  const big_thing_status = big_thingBadge && big_thingBadge?.status;

  const big_thing_coin = big_thingBadge && big_thingBadge?.badge_reward;

  const elite_status = eliteBadge && eliteBadge?.status;

  const elite_coin = eliteBadge && eliteBadge?.badge_reward;

  const userMobile = userData?.data?.mobile || "";

  const sliderRef = useRef(null);

  // const handlePrev = useCallback(() => {
  //   if (!sliderRef.current) return;

  //   sliderRef.current.swiper.slidePrev();
  // }, []);

  // const handleNext = useCallback(() => {
  //   if (!sliderRef.current) return;
  //   sliderRef.current.swiper.slideNext();
  // }, []);

  // dummy profile update
  const dummyProfileImage = (e) => {
    e.preventDefault();
    const fileName = e.target.getAttribute("data-file");
    const url = `${window.location.origin}/images/profileimages/${fileName}`;
    fetch(url).then(async (response) => {
      const contentType = response.headers.get("content-type");
      const blob = await response.blob();
      const file = new File([blob], fileName, { contentType });
      if (demoValue) {
        toast.error(t("no_update_in_demo"));
      } else {
        updateProfileApi(
          file,
          (success) => {
            toast.success(t("successfully_updated"));
          },
          (error) => {
            toast.error(error);
          }
        );
      }
    });
  };

  // onchange name and mobile
  const handleChange = (event) => {
    const field_name = event.target.name;
    const field_value = event.target.value;
    if (field_name === "mobile" && event.target.value?.length > 16) {
      event.target.value = field_value.slice(0, event.target.maxLength);
      return false;
    }
    setProfile((values) => ({ ...values, [field_name]: field_value }));
  };

  const validateForm = () => {
    if (!profile.name || !profile.mobile || !profile.email) {
      toast.error(t("Please fill in all details"));
      return false;
    }
    return true;
  };

  // update profile data
  const updateProfileData = () => {
    if (demoValue) {
      toast.error(t("no_update_in_demo"));
    } else {
      updateProfileDataApi(
        profile.email,
        profile.name,
        profile.mobile,
        (success) => {
          toast.success(t("successfully_updated"));
          updateUserDataInfo({ email: profile.email });
        },
        (error) => {
          console.log(error);
          toast.error(error);
        }
      );
    }
  };

  // form submit
  const formSubmit = (e) => {
    e.preventDefault();
    if (validateForm()) {
      updateProfileData();
    }
  };

  // // update profile image
  const handleImageChange = (e) => {
    e.preventDefault();
    if (demoValue) {
      toast.error(t("no_update_in_demo"));
    } else {
      updateProfileApi(
        e.target.files[0],
        (success) => {
          toast.success(t("successfully_updated"));
        },
        (error) => {
          if (error == "107") {
            toast.error("File not supported! Please select proper image type");
          }
        }
      );
    }
  };

  // one big think badges
  useEffect(() => {
    let totalQuestion =
      userData?.data && userData?.data?.userStatics.correct_answers;
    if (big_thing_status === "0" && totalQuestion == 5000) {
      setBadgesApi(
        "big_thing",
        (res) => {
          LoadNewBadgesData("big_thing", "1");
          toast.success(t(res?.data?.notification_body));
          const status = 0;
          UserCoinScoreApi({
            coins: big_thing_coin,
            title: t("big_thing_badge_reward"),
            status: status,
            onSuccess: (response) => {
              getusercoinsApi({
                onSuccess: (responseData) => {
                  updateUserDataInfo(responseData.data);
                },
                onError: (error) => {
                  console.log(error);
                },
              });
            },
            onError: (error) => {
              console.log(error);
            },
          });
        },
        (error) => {
          console.log(error);
        }
      );
    }
  }, []);

  // elite badge
  useEffect(() => {
    let totalUserCoins =
      userData?.data && userData?.data?.userProfileStatics.coins;
    if (elite_status === "0" && totalUserCoins == 5000) {
      setBadgesApi(
        "elite",
        (res) => {
          LoadNewBadgesData("elite", "1");
          toast.success(t(res?.data?.notification_body));
          const status = 0;
          UserCoinScoreApi({
            coins: elite_coin,
            title: t("elite_badge_reward"),
            status: status,
            onSuccess: (response) => {
              getusercoinsApi({
                onSuccess: (responseData) => {
                  updateUserDataInfo(responseData.data);
                },
                onError: (error) => {
                  console.log(error);
                },
              });
            },
            onError: (error) => {
              console.log(error);
            },
          });
        },
        (error) => {
          console.log(error);
        }
      );
    }
  }, []);

  const swiperOption = {
    loop: true,
    speed: 750,
    spaceBetween: 20,
    slidesPerView: 4,
    navigation: false,
    breakpoints: {
      0: {
        slidesPerView: 4.5,
      },

      768: {
        slidesPerView: 4.5,
      },

      992: {
        slidesPerView: 4.5,
      },
      1200: {
        slidesPerView: 5,
      },
    },
    autoplay: false,
  };

  // check if the quiz mode are unable or not
  const checkBookmarData = () => {
    if (
      systemconfig.quiz_zone_mode !== "1" &&
      systemconfig.guess_the_word_question !== "1" &&
      systemconfig.audio_mode_question !== "1" &&
      systemconfig.maths_quiz_mode !== "1"
    ) {
      toast.error("No Bookmark Questions Found");
      setShowBookMark(false);
    } else {
      setShowBookMark(true);
    }
  };

  useEffect(() => {
    checkBookmarData();
  }, [showBookMark]);

  useEffect(() => {
    if (!api) {
      return;
    }

    api.on("select", () => {});
  }, [api]);

  const onNext = () => {
    api.scrollNext();
  };

  const onPre = () => {
    api.scrollPrev();
  };
  return (
    <>
      <Breadcrumb title={t("profile")} content="" contentTwo="" />

      <div className="container px-2 mb-14 mt-[20px] md:mt-[40px] lg:mt-[56px]">
        <div className="">
          <div className="flex flex-wrap relative between-1200-1399:flex-nowrap justify-evenly gap-9">
            <div className=" h-max w-full xl:w-1/4 lg:w-2/3 md:w-full ">
              <div className="px-4 flex flex-col min-w-0 break-words  rounded-[16px] bg-[#f0f0f2] border border-[#f5f5f5] max-1200:p-[12px] p-[20px] relative">
                {/* Tab headers */}
                <LeftTabProfile />
              </div>
            </div>
            <div className="w-full md:w-full lg:w-[70%] xl:w-[70%]">
              <div className="morphisam !mt-0">
                <form onSubmit={formSubmit} className="block m-auto h-full">
                  {/* Content based on active tab */}

                  <div className="flex-center flex-col">
                    <div className="w-[120px] h-[120px] flex justify-center items-center bg-[#f9f9f9] rounded-full border-2 border-dashed border-[var(--text-color)] relative p-1.25 mt-[30px]">
                      {userData?.data && userData?.data?.profile ? (
                        <img
                          src={userData?.data?.profile}
                          alt="profile"
                          id="user_profile"
                          className="w-[100px] h-[100px] rounded-full"
                          onError={imgError}
                        />
                      ) : (
                        <ThemeSvg
                          src={userImg.src}
                          width="100px"
                          height="100px"
                          className="rounded-full"
                          alt="User"
                          colorMap={{
                            "#e13975": "var(--primary-color)",
                            "#6d1d50": "var(--secondary-color)",
                            "#f7ccdd": "var(--primary-light)",
                            "url(#linear-gradient)": "var(--primary-color)",
                            "linear-gradient": "var(--primary-color)",
                          }}
                        />
                      )}
                      <div className="select__profile">
                        <input
                          type="file"
                          name="profile"
                          className="w-0"
                          id="file"
                          onChange={handleImageChange}
                        />
                        <label
                          htmlFor="file"
                          className="cursor-pointer outline-none transition-all duration-300 align-middle m-0 absolute bottom-[20px] right-[-6px] bg-[#00bf7a] text-white h-[35px] w-[35px] rounded-full border border-white text-[0.75rem] flex justify-center items-center"
                        >
                          <em className="flex-center m-auto text-[16px]">
                            <FaPlus />
                          </em>
                        </label>
                        <input
                          type="text"
                          className="p-11 bg-black"
                          placeholder={t("upload_file")}
                          id="file1"
                          name="myfile"
                          disabled
                          hidden
                        />
                      </div>
                    </div>
                    <div className="flex-center pt-5">
                      <h3 className="text-text-color text-2xl md:text-[32px] ">
                        {userData?.data && userData?.data?.name}
                      </h3>
                    </div>
                    {userData?.data && userData?.data?.type === "gmail" ? (
                      <div className="flex-center pt-1 mb-2">
                        <span className="flex-center text-text-color gap-2">
                          <i className="flex-center">
                            <HiOutlineMail />
                          </i>
                          <p className="mb-0">{userData?.data?.email}</p>
                        </span>
                      </div>
                    ) : (
                      <div className="mobile__number justify-content-center">
                        <span>
                          <i>
                            <FaPhoneAlt />
                          </i>
                          <p>{userData?.data?.mobile}</p>
                        </span>
                      </div>
                    )}

                    <p className="w-full justify-center items-center flex before:right-[20px] before:ml-[-50%] after:left-[20px] after:mr-[-50%] relative text-text-color  text-[16px] font-normal text-center my-[22px] before:block before:bg-[#d3d3d3] before:h-[2px] before:w-[30%] before:opacity-100 before:align-middle before:relative after:block after:bg-[#d3d3d3] after:h-[2px] after:w-[30%] after:opacity-100 after:align-middle after:relative after:max-399:w-[20%] before:max-399:w-[20%]">
                      {t("or_select_avtar")}
                    </p>
                    {/* dummy image slider */}
                    <div className="w-[80%] lg:w-1/2 relative flex-center flex-wrap">
                      <div className="absolute left-[-43px] " onClick={onPre}>
                        <span>
                          <FaChevronLeft size={25} className="text-[#090029]" />
                        </span>
                      </div>
                      <Carousel
                        setApi={setApi}
                        opts={{
                          align: "start",
                        }}
                        className="w-full"
                      >
                        <CarouselContent>
                          {profileImages &&
                            profileImages.map((elem, index) => (
                              <CarouselItem
                                key={index}
                                className="max-399:basis-1/4 basis-1/5"
                              >
                                <div className="p-1 image_section">
                                  <div className="!bg-transparent rounded-lg  flex items-center justify-center aspect-square">
                                    <img
                                      src={elem?.img}
                                      alt="profile"
                                      className="cursor-pointer w-full h-full object-cover rounded-lg"
                                      onClick={(e) => dummyProfileImage(e)}
                                      data-file={elem?.img.split("/").pop()}
                                    />
                                  </div>
                                </div>
                              </CarouselItem>
                            ))}
                        </CarouselContent>
                      </Carousel>
                      <div className="absolute right-[-37px]" onClick={onNext}>
                        <span>
                          <FaChevronRight
                            size={25}
                            className="text-[#090029]"
                          />
                        </span>
                      </div>
                    </div>
                    <div className="p-4 flex flex-col w-full">
                      <div className="flex flex-wrap sm:flex-nowrap gap-3">
                        <div className="w-full md:w-1/2 max-767:pr-0">
                          <label htmlFor="fullName" className="inputIsideLabel">
                            <input
                              type="text"
                              name="name"
                              id="fullName"
                              placeholder={t("enter_name")}
                              defaultValue={
                                userData?.data && userData?.data?.name
                              }
                              onChange={handleChange}
                              required
                            />
                            <i className="custom-icon">
                              <FaRegUser />
                            </i>
                          </label>
                        </div>
                        <div className="w-full md:w-1/2 max-767:pl-0">
                          {userData?.data &&
                          userData?.data?.type === "gmail" ? (
                            <label
                              htmlFor="mobilenumber"
                              className="inputIsideLabel"
                            >
                              <input
                                type="number"
                                name="mobile"
                                id="mobilenumber"
                                placeholder={t("enter_num")}
                                defaultValue={userMobile}
                                onChange={handleChange}
                                min="0"
                                onWheel={(event) => event.currentTarget.blur()}
                              />

                              <i>
                                <FaMobileAlt />
                              </i>
                            </label>
                          ) : (
                            <label htmlFor="email" className="inputIsideLabel">
                              <input
                                type="email"
                                name="email"
                                id="email"
                                placeholder={t("enter_email")}
                                defaultValue={
                                  userData?.data && userData?.data?.email
                                }
                                onChange={handleChange}
                                min="0"
                                onWheel={(event) => event.currentTarget.blur()}
                              />

                              <i>
                                <HiOutlineMail />
                              </i>
                            </label>
                          )}
                        </div>
                      </div>
                      <button
                        className="p-[20px_48px] bg-primary-color w-full rounded-[16px] text-white text-capitalize mt-4"
                        type="submit"
                        value="submit"
                        name="submit"
                        id="mc-embedded-subscribe"
                      >
                        {t("update")}
                      </button>
                    </div>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};
export default withTranslation()(ProfileData);
