'use client'
import React, { useEffect, useState } from 'react'
import toast from 'react-hot-toast'
import { withTranslation } from 'react-i18next'
import { getUserProfilestatisticsApi, getUserStatisticsDataApi, updateUserDataInfo } from '@/store/reducers/userSlice'
import { useSelector } from 'react-redux'
import { UserCoinScoreApi, getusercoinsApi, setBadgesApi, getbattlestaticticsApi } from '@/store/actions/campaign'
import { badgesData, LoadNewBadgesData } from '@/store/reducers/badgesSlice'
// import { Progress, Tooltip } from 'antd'
import 'react-circular-progressbar/dist/styles.css'
import StatisticsPieChartCanvas from '@/components/Common/StatisticsPieChartCanvas'
import { imgError } from '@/utils'
import LeftTabProfile from '@/components/Profile/LeftTabProfile'
import Layout from '@/components/Layout/Layout'
import { t } from '@/utils'
import { useRouter } from 'next/router'
import { Tooltip } from '@radix-ui/react-tooltip'
import { CircularProgressbarWithChildren, buildStyles } from 'react-circular-progressbar'

const Statistics = () => {
  const router = useRouter()

  const userData = useSelector(state => state.User)

  const Badges = useSelector(badgesData)

  const big_thingBadge = Badges?.data?.find(badge => badge?.type === 'big_thing')

  const eliteBadge = Badges?.data?.find(badge => badge?.type === 'elite')

  const big_thing_status = big_thingBadge && big_thingBadge?.status

  const big_thing_coin = big_thingBadge && big_thingBadge?.badge_reward

  const elite_status = eliteBadge && eliteBadge?.status

  const elite_coin = eliteBadge && eliteBadge?.badge_reward

  const [battleStatisticsResult, setBattleStatisticsResult] = useState([])

  // website link

  // user profile data get and statics
  useEffect(() => {
    getUserProfilestatisticsApi(
      // userData?.data?.id,
      success => { },
      error => {
        // toast.error(error)
      }
    )
    // in static show total battle played
    getUserStatisticsDataApi(
      success => { },
      error => {
        // toast.error(error);
      }
    )
  }, [])

  // one big think badges
  useEffect(() => {
    let totalQuestion = userData?.data && userData?.data?.userStatics.correct_answers
    if (big_thing_status === '0' && totalQuestion == 5000) {
      setBadgesApi(
        'big_thing',
        res => {
          LoadNewBadgesData('big_thing', '1')
          toast.success(t(res?.data?.notification_body))
          const status = 0
          UserCoinScoreApi({
            coins: big_thing_coin,
            title: t('big_thing_badge_reward'),
            status: status,
            onSuccess: response => {
              getusercoinsApi({
                onSuccess: responseData => {
                  updateUserDataInfo(responseData.data)
                },
                onError: error => {
                  console.log(error)
                }
              })
            },
            onError: error => {
              console.log(error)
            }
          })
        },
        error => {
          console.log(error)
        }
      )
    }
  }, [])

  // elite badge
  useEffect(() => {
    let totalUserCoins = userData?.data && userData?.data?.userProfileStatics.coins
    if (elite_status === '0' && totalUserCoins == 5000) {
      setBadgesApi(
        'elite',
        res => {
          LoadNewBadgesData('elite', '1')
          toast.success(t(res?.data?.notification_body))
          const status = 0
          UserCoinScoreApi({
            coins: elite_coin,
            title: t('elite_badge_reward'),
            status: status,
            onSuccess: response => {
              getusercoinsApi({
                onSuccess: responseData => {
                  updateUserDataInfo(responseData.data)
                },
                onError: error => {
                  console.log(error)
                }
              })
            },
            onError: error => {
              console.log(error)
            }
          })
        },
        error => {
          console.log(error)
        }
      )
    }
  }, [])

  // get battleStatistics api call
  useEffect(() => {
    getbattlestaticticsApi({
      onSuccess: response => {
        setBattleStatisticsResult(response.myreport)
      },
      onError: error => {
        console.log(error)
      }
    })
  }, [])

  const correctAnswers = userData?.data?.userStatics.correct_answers
  const incorrectAnswers =
    parseInt(userData?.data?.userStatics.questions_answered) - parseInt(userData?.data?.userStatics.correct_answers)

  const totalQuestions = userData?.data?.userStatics.questions_answered
  const correctPercentage = (correctAnswers / totalQuestions) * 100
  const incorrectPercentage = (incorrectAnswers / totalQuestions) * 100

  const wonBattles =
    battleStatisticsResult && battleStatisticsResult[0] ? parseInt(battleStatisticsResult[0].Victories) || 0 : 0
  const drawBattles =
    battleStatisticsResult && battleStatisticsResult[0] ? parseInt(battleStatisticsResult[0].Drawn) || 0 : 0
  const lostBattles =
    battleStatisticsResult && battleStatisticsResult[0] ? parseInt(battleStatisticsResult[0].Loose) || 0 : 0

  // Calculate the total battles
  const totalBattles = wonBattles + drawBattles + lostBattles

  // Calculate percentages for each category
  const wonPercentage = (wonBattles / totalBattles) * 100
  const drawPercentage = (drawBattles / totalBattles) * 100
  const lostPercentage = (lostBattles / totalBattles) * 100

  const values = [
    { no: wonPercentage, arcColor: '#15ad5a' },
    { no: drawPercentage, arcColor: '#ffcc00' },
    { no: lostPercentage, arcColor: '#800080' }
  ]

  return (
    <Layout>
      <div className='container px-3 mb-14 mt-[20px] md:mt-[40px] lg:mt-[56px]'>
        <div className='flex flex-wrap between-1200-1399:flex-nowrap relative justify-evenly gap-9'>
          <div className='h-max w-full xl:w-1/4 lg:w-2/3 md:w-full'>
            <div className='px-4 flex flex-col min-w-0 break-words  rounded-[16px] bg-[#f0f0f2] border border-[#f5f5f5] max-1200:p-[12px] p-[20px] relative'>
              {/* Tab headers */}
              <LeftTabProfile />
            </div>
          </div>
          <div className='w-full md:w-full lg:w-[70%] xl:w-[70%] morphisam !m-0 !p-0 flex justify-center items-center'>
            <div className='!mt-0 flex flex-wrap justify-center items-center'>
              {/* question details */}
              <div className='w-full md:w-1/2 p-4'>
                <div className='  p-4 rounded-[16px] bg-white'>
                  <p className='text-[#212121] text-center text-2xl font-semibold'>{`${t('questions')} ${t(
                    'details'
                  )} `}</p>
                  <div className=''>
                    <div className='progressBar'>
                      <div className='w-[120px] m-[32px_auto] relative'>
                        {/* <Tooltip> */}
                        <CircularProgressbarWithChildren
                          value={incorrectPercentage}
                          strokeWidth={6}
                          styles={buildStyles({
                            pathTransition: 'none',
                            textColor: 'black',
                            trailColor: '#00bf7a',
                            pathColor: '#ff005c'
                          })}
                        >

                        </CircularProgressbarWithChildren>
                        {/* </Tooltip> */}
                        <div className='absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2 w-min rounded-full text-center'>
                          <span className='font-lato text-[24px] font-bold text-text-color inline-block p-[0px_10px]'>{userData?.data?.userStatics.questions_answered}</span>
                          <span className='text-black'> {t('att')}</span>
                        </div>
                      </div>
                    </div>
                    <div className='flex-center relative !justify-around'>
                      <span className='relative before:absolute rtl:before:mr-[-14px] ltr:before:ml-[-14px] before:top-[7px] before:bg-[#00bf7a] before:w-[8px] before:h-[8px] before:rounded-full font-sans text-[14px] font-normal text-text-color'>
                        {' '}
                        {t('correct')}{' '}
                        <span>
                          {userData?.data &&
                            (userData?.data?.userStatics.correct_answers
                              ? userData?.data?.userStatics.correct_answers
                              : '0')}
                        </span>
                      </span>
                      <span className='relative before:absolute rtl:before:mr-[-14px] ltr:before:ml-[-14px] before:top-[7px] before:bg-[#ff005c] before:w-[8px] before:h-[8px] before:rounded-full font-sans text-[14px] font-normal text-text-color'>
                        {' '}
                        {t('incorrect')}{' '}
                        <span>
                          {userData?.data &&
                            (parseInt(userData?.data?.userStatics.questions_answered) -
                              parseInt(userData?.data?.userStatics.correct_answers)
                              ? parseInt(userData?.data?.userStatics.questions_answered) -
                              parseInt(userData?.data?.userStatics.correct_answers)
                              : '0')}
                        </span>
                      </span>
                    </div>
                  </div>
                </div>
              </div>

              {/*battle statistics */}
              <div className='w-full md:w-1/2 p-4'>
                <div className=' p-4 rounded-[16px] bg-white'>
                  <p className='text-[#212121] text-center text-2xl font-semibold'>{t('battle_statistics')}</p>
                  <div className=''>
                    <StatisticsPieChartCanvas
                      width={120}
                      height={120}
                      values={values}
                      strokeWidth={8}
                      totalBattles={totalBattles}
                    />

                    {/* </div> */}
                    <div className='flex-center relative !justify-around max-991:gap-[30px] max-575:gap-[25px]'>
                      <span className='relative before:absolute rtl:before:mr-[-14px] ltr:before:ml-[-14px] before:top-[7px] before:bg-[#00bf7a] before:w-[8px] before:h-[8px] before:rounded-full font-sans text-[14px] font-normal text-text-colorcorr won'>
                        {' '}
                        {t('won')}{' '}
                        <span>
                          {battleStatisticsResult &&
                            battleStatisticsResult.map(ele => {
                              return <span>{ele?.Victories}</span>
                            })}
                        </span>
                      </span>
                      <span className='relative before:absolute rtl:before:mr-[-14px] ltr:before:ml-[-14px] before:top-[7px] before:bg-[#ffad01] before:w-[8px] before:h-[8px] before:rounded-full font-sans text-[14px] font-normal text-text-color'>
                        {' '}
                        {t('draw')}{' '}
                        <span>
                          {battleStatisticsResult &&
                            battleStatisticsResult.map(ele => {
                              return <span>{ele?.Drawn}</span>
                            })}
                        </span>
                      </span>
                      <span className='relative before:absolute rtl:before:mr-[-14px] ltr:before:ml-[-14px] before:top-[7px] before:bg-[#a868fa] before:w-[8px] before:h-[8px] before:rounded-full font-sans text-[14px] font-normal text-text-color'>
                        {' '}
                        {t('lost')}{' '}
                        <span>
                          {battleStatisticsResult &&
                            battleStatisticsResult.map(ele => {
                              return <span>{ele?.Loose}</span>
                            })}
                        </span>
                      </span>
                    </div>
                  </div>
                </div>
              </div>
              {/* quiz details */}
              <div className='w-full md:w-1/2 p-4'>
                <div className='quiz_details p-4 rounded-[16px] bg-white'>
                  <p className='text-[#212121] text-center text-2xl font-semibold'>{`${t('quiz')} ${t('details')}`}</p>
                  <div className='mt-11 flex flex-col '>
                    <span className='m-auto'>
                      <img src={userData?.data?.profile} alt='userProfileImage' onError={imgError} className='userProfile aspect-square' />
                    </span>
                  </div>

                  <div className='flex justify-between'>
                    <div className='mt-11 flex flex-col '>
                      <span className='text-[14px]'> {t('rank')}</span>
                      <span className='font-black'>
                        {' '}
                        {userData?.data && userData?.data?.userProfileStatics.all_time_rank}
                      </span>
                    </div>
                    <div className='mt-11 flex flex-col '>
                      <span className='text-[14px]'>{t('coins')}</span>
                      <span className='font-black'>{userData?.data && userData?.data?.userProfileStatics.coins}</span>
                    </div>
                    <div className='mt-11 flex flex-col '>
                      <span className='text-[14px]'>{t('score')}</span>
                      <span className='font-black'>
                        {' '}
                        {userData?.data && userData?.data?.userProfileStatics.all_time_score}
                      </span>
                    </div>
                  </div>
                </div>
              </div>
              {/* collected badges */}
              <div className='w-full md:w-1/2 p-4 statisticsBadges'>
                <div className='p-4 rounded-[16px] bg-white badges battle_statistics_badges '>
                  <p className='text-[#212121] text-center text-2xl font-semibold mb-0'>{t('collected_badges')}</p>
                  <ul className='flex justify-between mb-0 pb-0 max-575:!flex-col max-575:flex '>
                    {Badges.data && Badges.data?.length > 0 ? (
                      [...Object.values(Badges.data).filter(data => data.status === '1')]
                        .slice(0, 3)
                        .map((data, index) => (
                          <li className='flex-center md:w-1/3 w-full' key={index}>
                            <div
                              className='mb-5 text-center'
                              data-tooltip-id='my-tooltip'
                              data-tooltip-content={`${data.badge_note}`}
                            >
                              <div className='relative'>
                                <span className=" before:content-[&quot;⬢&quot;] before:text-[65px] before:text-primary-color" />
                                <img className='flex items-center justify-center top-0 left-0 right-0 bottom-0  h-[30px] object-contain absolute m-auto' src={data.badge_icon} alt='badges' />
                              </div>
                              <p className='md:truncate  md:w-[100px] '>{data.badge_label}</p>
                            </div>
                          </li>
                        ))
                    ) : (
                      <div className='no_badges'>
                        <span>{t('no_badges_founds')}</span>
                      </div>
                    )}
                  </ul>
                  <hr className='mt-0 mb-2' />
                  <p className='mb-0  font-semibold text-center' onClick={() => router.push('/profile/badges')}>
                    {t('view_all')}
                  </p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </Layout>
  )
}
export default withTranslation()(Statistics)
