import React, { Fragment, useEffect, useState } from "react";
import Skeleton from "react-loading-skeleton";
import { t } from "@/utils";

import { withTranslation } from "react-i18next";
import errorimg from "@/assets/images/error.svg";
import { truncate } from "@/utils";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";

const Upcoming = ({ data }) => {
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    if (loading) {
      setTimeout(() => {
        setLoading(false);
      }, 2000);
    }
  }, [loading]);

  return (
    <Fragment>
      <div
        className={`${
          data
            ? "grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-5"
            : "w-full"
        } ${
          loading ? "grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-5" : ""
        } my-14 `}
      >
        {loading ? (
          Array.from({ length: 6 })?.map((_, index) => (
            <Skeleton height={350} key={index} borderRadius={15} />
          ))
        ) : (
          <>
            {data ? (
              data?.map((upcomingData, index) => {
                return (
                  <div className="" key={index}>
                    <div className="rounded-[15px] p-[10px_14px] bg-[#0900290f] border-2 border-white/10  ">
                      <div className="card-image">
                        <img
                          className="w-full max-w-full object-contain m-auto rounded-[15px]"
                          src={upcomingData?.image}
                          alt="wrteam"
                        />
                      </div>
                      <div className="p-2">
                        <div className="text-left text-[20px] font-bold text-text-color">
                          <h3>{truncate(upcomingData?.name, 23)}</h3>
                          <p>{truncate(upcomingData?.description, 27)}</p>
                        </div>

                        <div className="p-[6px_12px]">
                          <div className="flex-center !justify-between pb-4 relative text-center before:absolute before:top-0 before:w-[1px] before:h-[52px] before:bg-[#ae9c9f21] after:absolute after:top-0 after:w-px after:h-[52px] after:bg-[#ae9c9f21] after:right-[66px] xl:after:right-[72px] lg:after:right-[62px]   before:left-[98px] xl:before:left-[98px] lg:before:left-[96px] ">
                            <div className="card-entry-fees">
                              <p className="text-[#6c757d] mb-1">
                                {t("entry_fees")}
                              </p>
                              <span className="text-text-color">
                                {upcomingData?.entry}
                              </span>
                            </div>
                            <div className="card-players">
                              <p className="text-[#6c757d] mb-1">
                                {t("start_on")}
                              </p>
                              <span className="text-text-color">
                                {upcomingData?.start_date}
                              </span>
                            </div>
                            <div className="card-ends-on">
                              <p className="text-[#6c757d] mb-1">
                                {t("ends_on")}
                              </p>
                              <span className="text-text-color">
                                {upcomingData?.end_date}
                              </span>
                            </div>
                          </div>

                          <div className="bottom-footer"></div>
                        </div>
                      </div>
                    </div>
                  </div>
                );
              })
            ) : (
              <div className="text-center m-auto pt-9 ">
                <div className="w-full h-24 mb-5">
                  <ThemeSvg
                    src={errorimg.src}
                    width="100%"
                    height="100%"
                    alt="Error"
                    colorMap={{
                      "#e03c75": "var(--primary-color)",
                      "#551948": "var(--secondary-color)",
                      "#3f1239": "var(--secondary-color)",
                      "#7b2167": "var(--secondary-color)",
                      "#ac5e9f": "var(--primary-color)",
                    }}
                  />
                </div>
                <p>{t("no_upcoming_contest")}</p>
              </div>
            )}
          </>
        )}
      </div>
    </Fragment>
  );
};

export default withTranslation()(Upcoming);
