import { withTranslation } from "react-i18next";
import { t } from "@/utils";
import errorimg from "@/assets/images/error.svg";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";
import { lazy, Suspense } from "react";
import QuestionSkeleton from "@/components/view/common/QuestionSkeleton";
import CatCompoSkeleton from "@/components/view/common/CatCompoSkeleton";
const FunandLearnIntro = lazy(() => import("./FunandLearnIntro"));

const FunandLearnSlider = (data) => {
  return (
    <>
      <div className="grid grid-cols-1 sm:grid-cols-2  lg:grid-cols-4 gap-4">
        {data.funandlearningloading ? (
          <div className="text-center">
            <CatCompoSkeleton />
          </div>
        ) : (
          <>
            {data.data ? (
              <>
                {data.data?.length > 0 &&
                  data.data.map((Fundata, key) => {
                    return (
                      <div key={key}>
                        <Suspense fallback={<QuestionSkeleton />}>
                          <FunandLearnIntro
                            categoryall={data.categoryall}
                            subcategoryall={data.subcategoryall}
                            data={Fundata}
                            funandlearn={Fundata?.id}
                          />
                        </Suspense>
                      </div>
                    );
                  })}
              </>
            ) : (
              <div className="text-center mt-4 commonerror">
                <div className="error_img">
                  <ThemeSvg
                    src={errorimg.src}
                    width="100%"
                    height="100%"
                    alt="Error"
                    colorMap={{
                      "#e03c75": "var(--primary-color)",
                      "#551948": "var(--secondary-color)",
                      "#3f1239": "var(--secondary-color)",
                      "#7b2167": "var(--secondary-color)",
                      "#ac5e9f": "var(--primary-color)",
                    }}
                  />
                </div>
                <p>{t("no_data_found")}</p>
              </div>
            )}
          </>
        )}
      </div>
    </>
  );
};
export default withTranslation()(FunandLearnSlider);
