import React, { useEffect } from 'react'
import PropTypes from 'prop-types'
import { withTranslation } from 'react-i18next'
import 'react-circular-progressbar/dist/styles.css'
import { useSelector } from 'react-redux'
import { groupbattledata } from '@/store/reducers/groupbattleSlice'
import { imgError } from '@/utils'
import { UserCoinScoreApi, getusercoinsApi } from '@/store/actions/campaign'
import { updateUserDataInfo } from '@/store/reducers/userSlice'
import { useRouter } from 'next/router'
import rightTickIcon from '../../../assets/images/check-circle-score-screen.svg'
import crossIcon from '../../../assets/images/x-circle-score-screen.svg'
import { t } from '@/utils'
import winnerBadge from '../../../assets/images/won bedge.svg'
import vsImg from '../../../assets/images/versus.svg'

const GroupBattleScore = ({ totalQuestions }) => {
  const navigate = useRouter()

  // store data get
  const userData = useSelector(state => state.User)
  const groupBattledata = useSelector(groupbattledata)

  const goToHome = () => {
    navigate.push('/')
  }

  // fetch data from local storage
  let user1correctanswer = groupBattledata.user1CorrectAnswer
  let user2correctanswer = groupBattledata.user2CorrectAnswer
  let user3correctanswer = groupBattledata.user3CorrectAnswer
  let user4correctanswer = groupBattledata.user4CorrectAnswer

  let user1name = groupBattledata.user1name
  let user2name = groupBattledata.user2name
  let user3name = groupBattledata.user3name
  let user4name = groupBattledata.user4name

  let user1uid = groupBattledata.user1uid
  let user2uid = groupBattledata.user2uid
  let user3uid = groupBattledata.user3uid
  let user4uid = groupBattledata.user4uid

  let user1image = groupBattledata.user1image
  let user2image = groupBattledata.user2image
  let user3image = groupBattledata.user3image
  let user4image = groupBattledata.user4image

  let entryFee = groupBattledata.entryFee

  // user data
  const alluseranswer = [user1correctanswer, user2correctanswer, user3correctanswer, user4correctanswer]

  const alluid = [user1uid, user2uid, user3uid, user4uid]

  // find max number
  const max = Math.max(...alluseranswer)

  let maxIndices = []

  for (let i = 0; i < alluseranswer?.length; i++) {
    if (alluseranswer[i] === max) {
      maxIndices.push(i)
    }
  }


  // Find the user IDs of all users with the max number of correct answers
  const usersWithMax = []
  for (const index of maxIndices) {
    usersWithMax.push(alluid[index])
  }

  // max user index
  const index = alluseranswer.indexOf(max)

  let winAmount = entryFee * (groupBattledata.totalusers / maxIndices?.length)

  useEffect(() => {
    if (usersWithMax.includes(userData?.data?.id) && entryFee > 0) {
      // Winner logic
      const status = 0
      UserCoinScoreApi({
        coins: Math.floor(winAmount),
        title: t('wonGroupBattle'),
        status: status,
        onSuccess: response => {
          getusercoinsApi({
            onSuccess: responseData => {
              updateUserDataInfo(responseData.data)
            },
            onError: error => {
              console.log(error)
            }
          })
        },
        onError: error => {
          console.log(error)
        }
      })
    }
  }, [])

  // all data store in array object
  let allData = [
    {
      uid: user1uid,
      image: user1image,
      name: user1name,
      correctAnswer: user1correctanswer
    },
    {
      uid: user2uid,
      image: user2image,
      name: user2name,
      correctAnswer: user2correctanswer
    },
    {
      uid: user3uid,
      image: user3image,
      name: user3name,
      correctAnswer: user3correctanswer
    },
    {
      uid: user4uid,
      image: user4image,
      name: user4name,
      correctAnswer: user4correctanswer
    }
  ]

  // // find the index of the winner
  // const winnerIndex = allData.findIndex(elem => elem.correctAnswer === max);

  // find the index of the winner with a non-empty name
  const winnerIndex = allData.findIndex(elem => elem.correctAnswer === max && elem.name !== '')

  // exclude the winner from allData
  // const remainingData = [...allData.slice(0, winnerIndex), ...allData.slice(winnerIndex + 1)];

  // // exclude the winner and users with empty names from allData
  const remainingData = allData.filter(elem => elem.name !== '' && elem.correctAnswer !== max)

  // sort remainingData based on correctAnswer in descending order
  remainingData.sort((a, b) => b.correctAnswer - a.correctAnswer)

  return (
    <React.Fragment>
      <div className='resultMorphisam'>
        {(() => {
          if (maxIndices?.length === 1) {
            if (userData?.data?.id === alluid[index]) {
              return (
                <div className='flex flex-col justify-center items-center text-center w-full'>
                  <p className='text-text-color md:text-[40px] text-[26px] font-bold'>{t('congrats')}</p>
                  <h3 className='text-[25px] mb-8 font-bold text-text-color'>{t('winner')}</h3>
                </div>
              )
            } else {
              return (
                <div className='flex flex-col justify-center items-center text-center w-full'>
                  <p className='text-text-color md:text-[40px] text-[26px] font-bold'>{t('good_luck_next_time')}</p>
                  <h3 className='text-[25px] mb-8 font-bold text-text-color'>{t('you_lose')}</h3>
                </div>
              )
            }
          } else if (maxIndices?.length >= 2) {
            return (
              <div className='flex flex-col justify-center items-center text-center w-full'>
                <h3 className='text-[25px] mb-8 font-bold text-text-color'>{t('tie')}</h3>
              </div>
            )
          }
        })()}

        <div
          className={`m-auto w-full flex-center text-center flex-wrap !mb-5 gap-[50px_0px] ${groupBattledata?.totalusers === 2 ? '' : 'flex-column'}`}
        >
          {(() => {
            if (maxIndices?.length === 1) {
              return (
                <>
                  <div
                    className={`mt-[30px] flex justify-between items-center text-center flex-wrap  ${remainingData.length > 1 ? 'flex-col w-full justify-around ' : 'w-full justify-around max-575:flex-col'
                      }`}
                  >
                    <div className='flex flex-col gap-3'>
                      {/* winner */}
                      <div className='break-all relative flex-center mx-auto mt-5'>
                        <img
                          src={allData[winnerIndex].image}
                          alt='user'
                          className='w-[120px] h-[120px] md:w-[150px] md:h-[150px] object-contain mb-[10px] rounded-full border-2 '
                          onError={e => imgError(e)}
                        />
                        <img src={winnerBadge.src} alt='winnerBadge' className='absolute bottom-0 right-3 md:right-0' />
                      </div>
                      <p className='text-base md:text-[22px] font-bold text-text-color'>{allData[winnerIndex].name}</p>
                      <div className='rightWrongAnsDiv'>
                        <span>
                          <img src={rightTickIcon.src} alt='' />
                          {allData[winnerIndex].correctAnswer}
                        </span>
                        <span>
                          <img src={crossIcon.src} alt='' />
                          {totalQuestions - allData[winnerIndex].correctAnswer}
                        </span>
                      </div>
                    </div>

                    {remainingData.length === 1 && (
                      <div className='  mt-5'>
                        <img className='object-contain w-auto aspect-square' src={vsImg.src} alt='versus' />
                      </div>
                    )}

                    {/* loser */}
                    <div
                      className={`mt-5 ${remainingData.length > 1 && 'mt-5 flex-row flex w-full justify-around flex-wrap gap-12'
                        }`}
                    >
                      {remainingData.map((elem, i) =>
                        elem?.uid !== '' ? (
                          <div className='flex flex-col gap-3' key={elem?.uid}>
                            <div className={`break-all relative flex-center mx-auto flex-col `}>
                              <img
                                src={elem?.image}
                                alt='user'
                                className='w-[125px] h-[125px] md:w-[150px] md:h-[150px] object-contain mb-[10px] rounded-full border-2'
                                onError={imgError}
                              />
                              <p className='text-base md:text-[22px] font-bold text-text-color'>{elem?.name}</p>
                            </div>
                            <div className='rightWrongAnsDiv'>
                              <span>
                                <img src={rightTickIcon.src} alt='' />
                                {elem?.correctAnswer}
                              </span>
                              <span>
                                <img src={crossIcon.src} alt='' />
                                {totalQuestions - elem?.correctAnswer}
                              </span>
                            </div>
                          </div>
                        ) : null
                      )}
                    </div>
                  </div>
                </>
              )
            } else if (maxIndices?.length > 1) {
              const filteredData = allData.filter(elem => elem.name !== '')

              // Sort filteredData based on correctAnswer in descending order
              const sortedData = filteredData.sort((a, b) => b.correctAnswer - a.correctAnswer)

              // Tie between more than two users
              return (
                <>
                  <div className='flex-row flex w-full justify-around flex-wrap gap-12'>
                    {sortedData.map((elem, i) => (
                      <div key={elem?.uid} className='flex flex-col gap-3 md:gap-5'>
                        <div className='break-all relative flex-center mx-auto flex-col '>
                          <img
                            className='w-[125px] h-[125px] md:w-[150px] md:h-[150px] object-contain mb-[10px] rounded-full border-2'
                            src={elem?.image}
                            alt='user'
                            onError={imgError}
                          />
                          <p className='text-base md:text-[22px] font-bold text-text-color'>{elem?.name}</p>
                        </div>
                        <div className='rightWrongAnsDiv'>
                          <span>
                            <img src={rightTickIcon.src} alt='' />
                            {elem?.correctAnswer}
                          </span>
                          <span>
                            <img src={crossIcon.src} alt='' />
                            {totalQuestions - elem?.correctAnswer}
                          </span>
                        </div>
                      </div>
                    ))}
                  </div>
                </>
              )
            }
          })()}
        </div>

        <div className='lifelineParantDiv !justify-evenly'>
          <div className=''>
            <button className='lifelinebtn mb-2' onClick={goToHome}>
              {t('home')}
            </button>
          </div>
        </div>
      </div>
    </React.Fragment>
  )
}

GroupBattleScore.propTypes = {
  coins: PropTypes.number.isRequired
}

export default withTranslation()(GroupBattleScore)
