import React, { useState, useRef, useEffect, Suspense, lazy } from "react";
import PropTypes from "prop-types";
import { withTranslation } from "react-i18next";
import Timer from "@/components/Common/Timer";
import {
  decryptAnswer,
  calculateScore,
  calculateCoins,
  showAnswerStatusClass,
  audioPlay,
} from "@/utils";
import { useDispatch, useSelector } from "react-redux";
import { sysConfigdata } from "@/store/reducers/settingsSlice";
import {
  setQuizCategoriesApi,
  UserCoinScoreApi,
  UserStatisticsApi,
} from "@/store/actions/campaign";
import { updateUserDataInfo } from "@/store/reducers/userSlice";
import {
  LoadQuizZoneCompletedata,
  percentageSuccess,
  questionsDataSuceess,
  resultTempDataSuccess,
  selecttempdata,
} from "@/store/reducers/tempDataSlice";
import { useRouter } from "next/router";
import { t } from "@/utils";
import QuestionTopSection from "@/components/view/common/QuestionTopSection";
import {
  setSecondSnap,
  setTotalSecond,
} from "@/store/reducers/showRemainingSeconds";
import QuestionSkeleton from "@/components/view/common/QuestionSkeleton";
const QuestionMiddleSectionOptions = lazy(() =>
  import("@/components/view/common/QuestionMiddleSectionOptions")
);
const MathmaniaQuestions = ({
  questions: data,
  timerSeconds,
  onOptionClick,
}) => {
  const [questions, setQuestions] = useState(data);
  const [currentQuestion, setCurrentQuestion] = useState(0);
  const [corrAns, setCorrAns] = useState(0);
  const [inCorrAns, setInCorrAns] = useState(0);
  const child = useRef(null);
  const scroll = useRef(null);

  const Score = useRef(0);

  const systemconfig = useSelector(sysConfigdata);

  const dispatch = useDispatch();

  const router = useRouter();

  // store data get
  const userData = useSelector((state) => state.User);

  let getData = useSelector(selecttempdata);

  const [answeredQuestions, setAnsweredQuestions] = useState({});

  const addAnsweredQuestion = (item) => {
    setAnsweredQuestions({ ...answeredQuestions, [item]: true });
  };

  setTimeout(() => {
    setQuestions(data);
  }, 500);

  const setNextQuestion = async () => {
    const nextQuestion = currentQuestion + 1;
    if (nextQuestion < questions?.length) {
      setCurrentQuestion(nextQuestion);
      child.current.resetTimer();
    } else {
      let coins = null;
      let userScore = null;

      let result_score = Score.current;
      let percentage = (100 * result_score) / questions?.length;
      UserStatisticsApi({
        questions_answered: questions?.length,
        correct_answers: result_score,
        category_id: questions[currentQuestion].category,
        percentage: percentage,
        onSuccess: (response) => { },
        onError: (error) => {
          console.log(error);
        },
      });
      userScore = await calculateScore(
        result_score,
        questions?.length,
        systemconfig?.maths_quiz_correct_answer_credit_score,
        systemconfig?.maths_quiz_wrong_answer_deduct_score
      );
      let status = "0";
      if (percentage >= Number(systemconfig.quiz_winning_percentage)) {
        coins = await calculateCoins(Score.current, questions?.length);
      
        if (getData.is_play === "0") {
          UserCoinScoreApi({
            coins: getData.is_premium == "1" ? coins * 2 : coins,
            score: getData.is_premium == "1" ? userScore * 2 : userScore,
            title: t("wonMathQuiz"),
            status: status,
            onSuccess: (response) => {
              updateUserDataInfo(response.data);
            },
            onError: (error) => {
              console.log(error);
            },
          });
        }
      } else {
        if (getData.is_play === "0") {
          UserCoinScoreApi({
            score: userScore,
            title: `${t("Math Mania")} ${t("lose")} `,
            statusL: status,
            onSuccess: (response) => {
              updateUserDataInfo(response.data);
            },
            onError: (error) => {
              console.log(error);
            },
          });
        }
      }
      // setTimeout(async () => {
      await onQuestionEnd(coins, userScore);
      // }, 2000)
      // set quiz categories
      if (getData.is_play === "0") {
        if (getData.maincat_id && getData.id) {
          setQuizCategoriesApi({
            type: 5,
            category_id: getData.maincat_id,
            subcategory_id: getData.id,
            onSuccess: (success) => { },
            onError: (error) => {
              console.log(error);
            },
          });
        } else {
          setQuizCategoriesApi({
            type: 5,
            category_id: getData.id,
            onSuccess: (success) => { },
            onError: (error) => {
              console.log(error);
            },
          });
        }
      }
    }
  };

  const onQuestionEnd = async (coins, userScore) => {
    const tempData = {
      totalQuestions: questions?.length,
      coins: coins,
      quizScore: userScore,
    };
    dispatch(resultTempDataSuccess(tempData));
    await router.push("/math-mania/result");
  };

  // button option answer check
  const handleAnswerOptionClick = async (selected_option) => {
    let seconds = child.current.getMinuteandSeconds();

    dispatch(setTotalSecond(timerSeconds));
    dispatch(setSecondSnap(seconds));

    if (!answeredQuestions.hasOwnProperty(currentQuestion)) {
      addAnsweredQuestion(currentQuestion);
      let { id, answer } = questions[currentQuestion];

      let decryptedAnswer = decryptAnswer(answer, userData?.data?.firebase_id);
      let result_score = Score.current;
      if (decryptedAnswer === selected_option) {
        result_score++;
        Score.current = result_score;
        setCorrAns(corrAns + 1);
      } else {
        setInCorrAns(inCorrAns + 1);
      }

      // this for only audio
      const currentIndex = currentQuestion;

      const currentQuestionq = questions[currentIndex];

      audioPlay(selected_option, currentQuestionq.answer);

      let update_questions = questions.map((data) => {
        return data?.id === id
          ? { ...data, selected_answer: selected_option, isAnswered: true }
          : data;
      });
      setQuestions(update_questions);
      setTimeout(async () => {
        await setNextQuestion();
      }, 1000);
      dispatch(percentageSuccess(result_score));
      onOptionClick(update_questions, result_score);
      dispatch(questionsDataSuceess(update_questions));
    }
  };

  // option answer status check
  const setAnswerStatusClass = (option) => {
    const currentIndex = currentQuestion;
    const currentQuestionq = questions[currentIndex];
    const color = showAnswerStatusClass(
      option,
      currentQuestionq.isAnswered,
      currentQuestionq.answer,
      currentQuestionq.selected_answer
    );
    return color;
  };

  const onTimerExpire = () => {
    let seconds = child.current.getMinuteandSeconds()
    child.current.pauseTimer();
    dispatch(setTotalSecond(timerSeconds))
    dispatch(setSecondSnap(seconds))
    setNextQuestion();
    setInCorrAns(inCorrAns + 1);
  };
  useEffect(() => {
    const queEnddatacorrect = corrAns;
    const queEnddataIncorrect = inCorrAns;
    LoadQuizZoneCompletedata(queEnddatacorrect, queEnddataIncorrect);
  }, [corrAns, inCorrAns]);

  return (
    <React.Fragment>
      <QuestionTopSection
        corrAns={corrAns}
        inCorrAns={inCorrAns}
        currentQuestion={currentQuestion}
        questions={questions}
        showAnswers={true}
        timerSeconds={timerSeconds}
        onTimerExpire={onTimerExpire}
        ref={child}
      />

      <Suspense fallback={<QuestionSkeleton />}>
        <QuestionMiddleSectionOptions
          questions={questions}
          currentQuestion={currentQuestion}
          setAnswerStatusClass={setAnswerStatusClass}
          handleAnswerOptionClick={handleAnswerOptionClick}
          probability={false}
          latex={true}
          math={true}
        />
      </Suspense>
    </React.Fragment>
  );
};

MathmaniaQuestions.propTypes = {
  questions: PropTypes.array.isRequired,
  onOptionClick: PropTypes.func.isRequired,
};

export default withTranslation()(MathmaniaQuestions);
