import React, { useEffect, useState } from "react";
import PropTypes from "prop-types";
import { withTranslation } from "react-i18next";
import "react-circular-progressbar/dist/styles.css";
import { useDispatch, useSelector } from "react-redux";
import { groupbattledata } from "@/store/reducers/groupbattleSlice";
import { imgError } from "@/utils";
import {
  UserCoinScoreApi,
  getusercoinsApi,
  setBadgesApi,
  setbattlestaticticsApi,
} from "@/store/actions/campaign";
import { badgesData, LoadNewBadgesData } from "@/store/reducers/badgesSlice";
import toast from "react-hot-toast";
import { updateUserDataInfo } from "@/store/reducers/userSlice";
import { useRouter } from "next/navigation";
// import vsImg from '../../../assets/images/versus.svg'
import vsImg from "../../../assets/images/versus.svg";
import showScoreVsImg from "../../../assets/images/versus.svg";
import rightTickIcon from "../../../assets/images/check-circle-score-screen.svg";
import crossIcon from "../../../assets/images/x-circle-score-screen.svg";
import winnerBadge from "../../../assets/images/won bedge.svg";
import userImg from "../../../assets/images/user.svg";
import ThemeSvg from "@/components/ThemeSvg/ThemeSvg";
import { t } from "@/utils";

const ShowScore = ({
  score,
  totalQuestions,
  onReviewAnswersClick,
  reviewAnswer,
  goBack,
}) => {
  const navigate = useRouter();

  const goToHome = () => {
    navigate.push("/");
  };

  // store data get
  const userData = useSelector((state) => state.User);

  const groupBattledata = useSelector(groupbattledata);

  const dispatch = useDispatch();

  const badgesdata = useSelector(badgesData);

  const quiz_warriorBadge = badgesdata?.data?.find(
    (badge) => badge?.type === "quiz_warrior"
  );

  const quiz_warrior_status = quiz_warriorBadge && quiz_warriorBadge?.status;

  const quiz_warrior_coin =
    quiz_warriorBadge && quiz_warriorBadge?.badge_reward;

  let user1point = groupBattledata.user1point;
  let user1CorrectAnswer = groupBattledata.user1CorrectAnswer;
  let user2CorrectAnswer = groupBattledata.user2CorrectAnswer;
  let user2point = groupBattledata.user2point;
  let user1name = groupBattledata.user1name;
  let user2name = groupBattledata.user2name;
  let user1uid = groupBattledata.user1uid;
  let user2uid = groupBattledata.user2uid;
  let user1image = groupBattledata.user1image;
  let user2image = groupBattledata.user2image;
  let entryFee = groupBattledata.entryFee;

  // winner id
  const comparePointsAndRetrieveUserIDs = () => {
    if (user1point > user2point) {
      // user1point is greater than user2point
      return user1uid;
    } else if (user2point > user1point) {
      // user2point is greater than user1point
      return user2uid;
    } else {
      // user1point and user2point are equal
      return 0;
    }
  };

  // login user
  const user2IdGet = () => {
    if (userData?.data?.id == user1uid) {
      return user2uid;
    } else {
      return user1uid;
    }
  };

  let counter = 0;

  // quiz warrior badge
  const checkCondition = (userData, user1uid, user1point, user2point) => {
    if (userData?.data?.id === user1uid && user1point > user2point) {
      counter++;
      if (quiz_warrior_status === "0" && counter === 3) {
        setBadgesApi(
          "quiz_warrior",
          (res) => {
            LoadNewBadgesData("quiz_warrior", "1");
            toast.success(t(res?.data?.notification_body));
            const status = 0;
            UserCoinScoreApi({
              coins: quiz_warrior_coin,
              title: t("quiz_warrior_badge_reward"),
              status: status,
              onSuccess: (response) => {
                getusercoinsApi({
                  onSuccess: (responseData) => {
                    updateUserDataInfo(responseData.data);
                  },
                  onError: (error) => {
                    console.log(error);
                  },
                });
              },
              onError: (error) => {
                console.log(error);
              },
            });
          },
          (error) => {
            console.log(error);
          }
        );
      }
    } else if (userData?.data?.id === user2uid && user2point > user1point) {
      counter++;
      if (quiz_warrior_status === "0" && counter === 3) {
        setBadgesApi(
          "quiz_warrior",
          (res) => {
            LoadNewBadgesData("quiz_warrior", "1");
            toast.success(t(res?.data?.notification_body));
            const status = 0;
            UserCoinScoreApi({
              coins: quiz_warrior_coin,
              title: t("quiz_warrior_badge_reward"),
              status: status,
              onSuccess: (response) => {
                getusercoinsApi({
                  onSuccess: (responseData) => {
                    updateUserDataInfo(responseData.data);
                  },
                  onError: (error) => {
                    console.log(error);
                  },
                });
              },
              onError: (error) => {
                console.log(error);
              },
            });
          },
          (error) => {
            console.log(error);
          }
        );
      }
    } else {
      counter = 0;
    }
  };

  useEffect(() => {
    checkCondition(userData, user1uid, user1point, user2point);
  }, []);

  // set battle statistics api
  useEffect(() => {
    let compareBattledata = comparePointsAndRetrieveUserIDs();
    let user2uidData = user2IdGet();
    setbattlestaticticsApi({
      user_id1: userData?.data?.id,
      user_id2: user2uidData,
      winner_id: compareBattledata,
      is_drawn: compareBattledata ? 0 : 1,
    });
  }, []);

  const alluseranswer = [user1point, user2point];

  const alluid = [user1uid, user2uid];

  // find max number
  const max = Math.max(...alluseranswer);

  let maxIndices = [];

  for (let i = 0; i < alluseranswer?.length; i++) {
    if (alluseranswer[i] === max) {
      maxIndices.push(i);
    }
  }

  // Find the user IDs of all users with the max number of correct answers
  const usersWithMax = [];
  for (const index of maxIndices) {
    usersWithMax.push(alluid[index]);
  }

  let winAmount = entryFee * (groupBattledata.totalusers / maxIndices?.length);

  useEffect(() => {
    if (
      !groupBattledata.showScore &&
      usersWithMax.includes(userData?.data?.id) &&
      entryFee > 0
    ) {
      // Winner logic
      const status = 0;
      UserCoinScoreApi({
        coins: Math.floor(winAmount),
        title: t("wonBattle"),
        status: status,
        onSuccess: (response) => {
          getusercoinsApi({
            onSuccess: (responseData) => {
              updateUserDataInfo(responseData.data);
            },
            onError: (error) => {
              console.log(error);
            },
          });
        },
        onError: (error) => {
          console.log(error);
        },
      });
    }
  }, []);

  return (
    <React.Fragment>
      <div className="resultMorphisam">
        {(() => {
          if (userData?.data?.id == user1uid && user1point > user2point) {
            return (
              <>
                <div className="flex flex-col justify-center items-center text-center w-full">
                  <p className="text-text-color text-[40px] font-bold">
                    {t("victory")}
                  </p>
                  <h3 className="text-[25px] mb-8 font-bold text-text-color">
                    {t("congrats")}
                  </h3>
                  {entryFee > 0 && user2uid !== "000" ? (
                    <div className="flex justify-center items-center border-2 border-[#00bf7a] rounded-[8px] w-[50%] p-3 text-[32px] m-3 font-bold text-text-color bgcolor max-575:text-[18px]">
                      <span>{t(`You Won ${winAmount} Coins`)}</span>
                    </div>
                  ) : null}
                </div>
              </>
            );
          } else if (
            userData?.data?.id == user1uid &&
            user1point < user2point
          ) {
            return (
              <div className="flex flex-col justify-center items-center text-center w-full">
                <p className="text-text-color text-[40px] font-bold">
                  {t("defeat")}
                </p>
                <h3 className="text-[25px] mb-8 font-bold text-text-color">
                  {t("better_luck_next_time")}
                </h3>
                {entryFee > 0 && user2uid !== "000" ? (
                  <div className="flex justify-center items-center border-2 !border-[#ff005c] rounded-[8px] w-[50%] p-3 text-[32px] m-3 font-bold text-text-color bgcolor ">
                    <span>
                      {t("you_lose")}&nbsp;{entryFee}&nbsp;{t("coins")}
                    </span>
                  </div>
                ) : null}
              </div>
            );
          } else if (
            userData?.data?.id == user2uid &&
            user1point > user2point
          ) {
            return (
              <div className="flex flex-col justify-center items-center text-center w-full">
                <p className="text-text-color text-[40px] font-bold">
                  {t("defeat")}
                </p>
                <h3 className="text-[25px] mb-8 font-bold text-text-color">
                  {t("better_luck_next_time")}
                </h3>

                {entryFee > 0 && user2uid !== "000" ? (
                  <div className="flex justify-center items-center !border-2 !border-[#ff005c] rounded-[8px] w-[50%] p-3 text-[32px] m-3 font-bold text-text-color bgcolor max-575:text-[18px]">
                    <span>
                      {t("you_lose")}&nbsp;{entryFee}&nbsp;{t("coins")}
                    </span>
                  </div>
                ) : null}
              </div>
            );
          } else if (
            userData?.data?.id == user2uid &&
            user1point < user2point
          ) {
            return (
              <div className="flex flex-col justify-center items-center text-center w-full">
                <p className="text-text-color text-[40px] font-bold">
                  {t("victory")}
                </p>
                <h3 className="text-[25px] mb-8 font-bold text-text-color">
                  {t("congrats")}
                </h3>
                {entryFee > 0 && user2uid !== "000" ? (
                  <div className="flex justify-center items-center border-2 border-[#00bf7a] rounded-[8px] w-[50%] p-3 text-[32px] m-3 font-bold text-text-color bgcolor max-575:text-[18px]">
                    <span>{t(`You Won ${winAmount} Coins`)}</span>
                  </div>
                ) : null}
              </div>
            );
          } else if (user1point == user2point) {
            return (
              <div className="flex flex-col justify-center items-center text-center w-full mb-2 md:mb-4 lg:mb-6">
                <h3 className="text-xl sm:text-[25px]  font-bold text-text-color">
                  {t("tie")}
                </h3>
              </div>
            );
          }
        })()}

        {(() => {
          if (user1point > user2point) {
            return (
              <div className="mt-[30px] w-full md:w-[80%]  lg:w-[60%] flex justify-between items-center text-center flex-wrap mx-auto flex-col sm:flex-row gap-4">
                <div className="flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user1image ? (
                      <img
                        src={user1image}
                        alt="user"
                        className="w-[150px] h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="150px"
                        height="150px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                    <img
                      src={winnerBadge.src}
                      alt="winnerBadge"
                      className="absolute bottom-0 right-0"
                    />
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user1name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span>
                      <img src={rightTickIcon.src} alt="" />
                      {user1CorrectAnswer}
                    </span>

                    <span>
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user1CorrectAnswer}
                    </span>
                  </div>
                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user1point}
                  </p>
                </div>

                {/* vs */}
                <div className="versus_screen">
                  <img
                    className="object-contain w-auto aspect-square"
                    src={vsImg.src}
                    alt="versus"
                  />
                </div>

                <div className="flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user2image ? (
                      <img
                        src={user2image}
                        alt="user"
                        className="w-[150px] h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="150px"
                        height="150px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user2name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span>
                      <img src={rightTickIcon.src} alt="" />
                      {user2CorrectAnswer}
                    </span>

                    <span>
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user2CorrectAnswer}
                    </span>
                  </div>
                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user2point}
                  </p>
                </div>
              </div>
            );
          } else if (user1point < user2point) {
            return (
              <div className="mt-[30px] w-full md:w-[80%]  lg:w-[60%] flex justify-between items-center text-center flex-wrap mx-auto flex-col sm:flex-row gap-4">
                <div className="login_winner flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user2image ? (
                      <img
                        src={user2image}
                        alt="user"
                        className="w-[150px] h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="150px"
                        height="150px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                    <img
                      src={winnerBadge.src}
                      alt="winnerBadge"
                      className="absolute bottom-0 right-0"
                    />
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user2name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span>
                      <img src={rightTickIcon.src} alt="" />
                      {user2CorrectAnswer}
                    </span>

                    <span>
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user2CorrectAnswer}
                    </span>
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user2point}
                  </p>
                </div>

                {/* vs */}
                <div>
                  <img
                    className="object-contain w-auto aspect-square"
                    src={showScoreVsImg.src}
                    alt="versus"
                  />
                </div>

                <div className="flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user1image ? (
                      <img
                        src={user1image}
                        alt="user"
                        className="w-[150px] h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="150px"
                        height="150px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user1name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span>
                      <img src={rightTickIcon.src} alt="" />
                      {user1CorrectAnswer}
                    </span>

                    <span>
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user1CorrectAnswer}
                    </span>
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user1point}
                  </p>
                </div>
              </div>
            );
          } else if (user1point == user2point) {
            return (
              <div className="mt-[30px] w-full md:w-[80%]  lg:w-[60%] flex justify-between items-center text-center flex-wrap mx-auto flex-col sm:flex-row gap-4">
                <div className="login_winner flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user1image ? (
                      <img
                        src={user1image}
                        alt="user"
                        className="w-[95px] md:w-[150px] h-[95px] md:h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="95px"
                        height="95px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user1name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span>
                      <img src={rightTickIcon.src} alt="" />
                      {user1CorrectAnswer}
                    </span>

                    <span>
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user1CorrectAnswer}
                    </span>
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user1point}
                  </p>
                </div>

                {/* vs */}
                <div className="versus_screen">
                  <img
                    className="object-contain w-auto aspect-square"
                    src={showScoreVsImg.src}
                    alt="versus"
                  />
                </div>

                <div className="flex flex-col gap-2 md:gap-3">
                  <div className="w-[195px] relative flex-center mx-auto">
                    {user2image ? (
                      <img
                        src={user2image}
                        alt="user"
                        className="w-[95px] md:w-[150px] h-[95px] md:h-[150px] object-contain mb-[10px] rounded-full border-2"
                        onError={imgError}
                      />
                    ) : (
                      <ThemeSvg
                        src={userImg.src}
                        width="95px"
                        height="95px"
                        className="object-contain mb-[10px] rounded-full border-2"
                        alt="User"
                        colorMap={{
                          "#e13975": "var(--primary-color)",
                          "#6d1d50": "var(--secondary-color)",
                          "#f7ccdd": "var(--primary-light)",
                        }}
                      />
                    )}
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {user2name}
                  </p>

                  <div className="rightWrongAnsDiv">
                    <span className="rightAns">
                      <img src={rightTickIcon.src} alt="" />
                      {user2CorrectAnswer}
                    </span>

                    <span className="wrongAns">
                      <img src={crossIcon.src} alt="" />
                      {totalQuestions - user2CorrectAnswer}
                    </span>
                  </div>

                  <p className="text-[22px] font-bold text-text-color">
                    {" "}
                    {t("score")}: {user2point}
                  </p>
                </div>
              </div>
            );
          }
        })()}

        <div className="lifelineParantDiv !justify-evenly">
          {reviewAnswer ? (
            <div>
              <button
                className="lifelinebtn mb-2"
                onClick={onReviewAnswersClick}
              >
                {t("review_answers")}
              </button>
            </div>
          ) : (
            ""
          )}
          <div>
            <button className="lifelinebtn mb-2" onClick={goBack}>
              {t("back")}
            </button>
          </div>
          <div>
            <button className="lifelinebtn mb-2" onClick={goToHome}>
              {t("home")}
            </button>
          </div>
        </div>
      </div>
    </React.Fragment>
  );
};

ShowScore.propTypes = {
  coins: PropTypes.number.isRequired,
};
export default withTranslation()(ShowScore);
