"use client";
import React, { useRef, useState } from "react";
import { FaRegCopy, FaWhatsapp, FaFacebook } from "react-icons/fa";
import { FaXTwitter } from "react-icons/fa6";
import { withTranslation } from "react-i18next";
import { useSelector } from "react-redux";
import Link from "next/link";
import giftImg from "@/assets/images/img.svg";
import dynamic from "next/dynamic";
import LeftTabProfile from "../Profile/LeftTabProfile";
import { LoadNewBadgesData, badgesData } from "@/store/reducers/badgesSlice";
import {
  UserCoinScoreApi,
  getusercoinsApi,
  setBadgesApi,
} from "@/store/actions/campaign";
import toast from "react-hot-toast";
import { updateUserDataInfo } from "@/store/reducers/userSlice";
import { t } from "@/utils";
import { ImageToSvg } from "../ImageToSvg/ImageToSvg";
import { sysConfigdata } from "@/store/reducers/settingsSlice";
import coinimg from "@/assets/images/coin.svg";
import ThemeSvg from "../ThemeSvg";
const Layout = dynamic(() => import("../Layout/Layout"), { ssr: false });

const Invite_friends = () => {
  const clickCount = useRef(0);

  const Badges = useSelector(badgesData);

  const sharing_caringBadge = Badges?.data?.find(
    (badge) => badge?.type === "sharing_caring"
  );

  const sharing_caring_status =
    sharing_caringBadge && sharing_caringBadge?.status;

  const systemconfig = useSelector(sysConfigdata);

  // refer_coin

  const [copyState, setCopyState] = useState(0);

  const userData = useSelector((state) => state.User);

  const clickToCopy = (event) => {
    event.preventDefault();
    if (navigator.clipboard !== undefined) {
      //Chrome
      navigator.clipboard
        .writeText(userData?.data && userData?.data?.refer_code)
        .then(
          function () {},
          function (err) {}
        );
    } else if (window.clipboardData) {
      // Internet Explorer
      window.clipboardData.setData(
        "Text",
        userData?.data && userData?.data?.refer_code
      );
    }

    setCopyState(1);
    setTimeout(() => {
      setCopyState(0);
    }, 1000);
  };

  // share social media and sharing caring badge
  const shareAppButton = (e) => {
    e.preventDefault();
    clickCount.current++;
    if (sharing_caring_status === "0" && clickCount.current == 50) {
      setBadgesApi(
        "sharing_caring",
        (res) => {
          LoadNewBadgesData("sharing_caring", "1");
          toast.success(t(res?.data?.notification_body));
          const status = 0;
          UserCoinScoreApi({
            coins: sharing_caring_coin,
            title: t("sharing_caring_badge_reward"),
            status: status,
            onSuccess: (response) => {
              getusercoinsApi({
                onSuccess: (responseData) => {
                  updateUserDataInfo(responseData.data);
                },
                onError: (error) => {
                  console.log(error);
                },
              });
            },
            onError: (error) => {
              console.log(error);
            },
          });
        },
        (error) => {
          console.log(error);
        }
      );
    }
  };
  const refferMessage = `${t("hey_there_earn")} ${systemconfig.refer_coin} ${t(
    "coins"
  )} ${t("apply_referral_code")} ${userData && userData?.data?.refer_code}
 ${t("compete_for_prizes")} ${
    process.env.NEXT_PUBLIC_APP_WEB_URL + "/auth/sign-up/"
  }`;
  return (
    <Layout>
      <div className="container px-2 mb-14 mt-[20px] md:mt-[40px] lg:mt-[56px]">
        <div className="flex flex-wrap relative between-1200-1399:flex-nowrap justify-evenly gap-9">
          <div className="h-max w-full xl:w-1/4 lg:w-2/3 md:w-full">
            <div className="px-4 flex flex-col min-w-0 break-words  rounded-[16px] bg-[#f0f0f2] border border-[#f5f5f5] max-1200:p-[12px] p-[20px] relative">
              {/* Tab headers */}
              <LeftTabProfile />
            </div>
          </div>
          <div className="w-full md:w-full lg:w-[70%] xl:w-[70%] morphisam !m-0 !p-0">
            <div className="!mt-0 flex flex-wrap">
              <div>
                <div className="p-7">
                  <h3 className="text-center">
                    <b className="text-[#090929] font-sans text-[42px] font-semibold max-575:text-[24px]">
                      {" "}
                      {t("refer_earn")}
                    </b>
                  </h3>

                  <div className="py-7 relative flex-center after:z-0 after:absolute after:top-[30px] after:ml-[-50px] after:w-[300px] after:h-[180px] after:blur-[75px] after:rounded-[70px] after:bg-[rgba(239,83,135,0.871)] after:opacity-[0.6]">
                    <div className="relative w-[165px] h-[180px]">
                      <ThemeSvg
                        src={giftImg.src}
                        alt="invite-friend"
                        width="100%"
                        height="100%"
                        colorMap={{
                          // Primary color mappings
                          "#E85FB2": "var(--primary-color)",
                          "#8C2968": "var(--primary-color)",
                          "#7F0047": "var(--primary-color)",
                          "#891455": "var(--primary-color)",
                          "#AC5A88": "var(--primary-color)",
                          "#C995B2": "var(--primary-color)",
                          "#E0C2D3": "var(--primary-color)",
                          "#FF7087": "var(--primary-color)",
                          "#FDBB46": "var(--primary-color)",
                          "#FD8946": "var(--primary-color)",

                          // Secondary color mappings
                          "#090029": "var(--secondary-color)",
                          "#282f39": "var(--secondary-color)",
                        }}
                      />
                    </div>
                    {/* <ImageToSvg imageUrl={giftImg.src} className="custom-svg" /> */}
                  </div>

                  <div className=" flex-center !items-end ">
                    <span className="text-2xl md:text-4xl text-[#090929] font-bold flex gap-2 items-center">
                      <div className="w-5 h-5">
                        <ThemeSvg
                          src={coinimg.src}
                          width="100%"
                          height="100%"
                          alt="Coin"
                          colorMap={{
                            // Primary color mappings
                            "#E85FB2": "var(--primary-color)",
                            "#8C2968": "var(--primary-color)",
                            "#7F0047": "var(--primary-color)",
                            "#891455": "var(--primary-color)",
                            "#AC5A88": "var(--primary-color)",
                            "#C995B2": "var(--primary-color)",
                            "#E0C2D3": "var(--primary-color)",
                            "#FF7087": "var(--primary-color)",
                            "#ef5488": "var(--primary-color)",
                            "#FDBB46": "var(--primary-color)",
                            "#FD8946": "var(--primary-color)",

                            // Secondary color mappings
                            "#090029": "var(--secondary-color)",
                            "#282f39": "var(--secondary-color)",
                          }}
                        />
                      </div>
                      {systemconfig.refer_coin}{" "}
                    </span>
                    <span className="ml-2 text-xl md:text-2xl font-bold text-[#090929] items-baseline">
                      {t("get_free_coin")}
                    </span>
                  </div>

                  <p className="font-sans text-base md:text-[18px] font-bold text-gray-500 sm:px-[50px] px-0  py-[30px] text-center">
                    {t("refer_and_earn_text")}
                  </p>

                  <div className="bg-gradient-to-r from-primary-color to-[#981b46] rounded-[8px] text-white p-[20px] flex-center flex-col">
                    <span>
                      <b>{t("your_referral_code")}</b>
                    </span>
                    <div className="relative m-[30px_auto] after:absolute  after:left-0 after:top-0 after:w-full after:h-full after:z-[-2] after:rounded-[50px]">
                      <span className="bg-transparent rounded-[16px] border-dashed text-white font-bold border-[2px] border-[#ddd] px-[50px] py-[12px]">
                        {userData && userData?.data?.refer_code}
                      </span>
                      <button className="h-[45px] px-[20px] rounded-[16px] bg-transparent cursor-pointer text-white absolute mt-[-12px] ml-[-58px] transition-all duration-[2000ms] ease-out inline-block shadow-[inset_0_0_0_0_#313131] border-none">
                        <span className="mt-1 inline-block">
                          <Link
                            href={""}
                            onClick={(event) => {
                              clickToCopy(event);
                            }}
                            className="hover:text-primary-color "
                          >
                            <i>
                              <FaRegCopy />
                            </i>
                          </Link>
                        </span>
                      </button>
                    </div>
                    <span>{t("send_to_friend")}</span>
                  </div>
                </div>

                <div className="flex-center flex-col my-4 md:my-6 gap-3">
                  <p className="text-[#090929] font-sans text-[24px] font-bold mb-0">
                    <b>{t("invite_now")}</b>
                  </p>
                  <ul className="list-none flex justify-center items-center mb-3">
                    <li className="mr-5 cursor-pointer">
                      <a
                        href={
                          "https://web.whatsapp.com/send?text=" + refferMessage
                        }
                        target="_blank"
                        rel="noreferrer"
                      >
                        <i className="text-white text-[26px] bg-gradient-to-r from-[var(--primary-color)] to-[#981b46] rounded-full p-[10px] flex justify-center items-center">
                          <FaWhatsapp />
                        </i>
                      </a>
                    </li>
                    <li className="mr-5 cursor-pointer">
                      <a
                        href={
                          "https://twitter.com/intent/tweet?text=" +
                          refferMessage
                        }
                        target="_blank"
                        rel="noreferrer"
                      >
                        <i className="text-white text-[26px] bg-gradient-to-r from-[var(--primary-color)] to-[#981b46] rounded-full p-[10px] flex justify-center items-center">
                          <FaXTwitter />
                        </i>
                      </a>
                    </li>
                    <li className="mr-5 cursor-pointer">
                      <a
                        href={
                          "http://www.facebook.com/sharer.php?u=" +
                          window.location.protocol +
                          "//" +
                          window.location.hostname +
                          "&quote=" +
                          refferMessage
                        }
                        target="_blank"
                        rel="noreferrer"
                      >
                        <i className="text-white text-[26px] bg-gradient-to-r from-[var(--primary-color)] to-[#981b46] rounded-full p-[10px] flex justify-center items-center">
                          <FaFacebook />
                        </i>
                      </a>
                    </li>
                  </ul>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </Layout>
  );
};
export default withTranslation()(Invite_friends);
