'use client'
import React, { useState, useRef, useEffect } from 'react'
import { FaLock, FaMobileAlt } from 'react-icons/fa'
import { HiOutlineMail } from 'react-icons/hi'
import { FcGoogle } from 'react-icons/fc'
import toast from 'react-hot-toast'
import { checkUserExist, register } from '@/store/reducers/userSlice'
import FirebaseData from '@/utils/Firebase'
import { useRouter } from 'next/navigation'
import Link from 'next/link'
import { BsEyeSlash, BsEye } from 'react-icons/bs'
import NewUser from '@/components/Common/NewUser.jsx'
import { t } from '@/utils'
import { withTranslation } from 'react-i18next'
import dynamic from 'next/dynamic'
import { handleFirebaseAuthError } from '@/utils'
import { GoogleAuthProvider, getAdditionalUserInfo, signInWithEmailAndPassword, signInWithPopup } from 'firebase/auth'
import { sysConfigdata } from '@/store/reducers/settingsSlice'
import { useSelector } from 'react-redux'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
const Layout = dynamic(() => import('@/components/Layout/Layout'), { ssr: false })

const Login = () => {
  const [loading, setLoading] = useState(false)

  const [newUserScreen, setNewUserScreen] = useState(false)

  const [type, setType] = useState('password')

  const [Icon, setIcon] = useState(<BsEyeSlash />)

  const { auth } = FirebaseData()

  const [profile, setProfile] = useState({
    name: '',
    mobile: '',
    email: '',
    profile: '',
    all_time_rank: '',
    all_time_score: '',
    coins: '',
    friends_code: ''
  })

  const emailRef = useRef()

  const passwordRef = useRef()

  const router = useRouter()

  const systemconfig = useSelector(sysConfigdata)
  // signin
  const signin = async (email, password) => {
    try {
      const userCredential = await signInWithEmailAndPassword(auth, email, password)
      return userCredential
    } catch (error) {
      throw error
    }
  }

  //email signin
  const handleSignin = async e => {
    e.preventDefault()
    setLoading(true)
    const email = emailRef.current.value
    const password = passwordRef.current.value
    try {
      let userdata = await signin(email, password)
      setProfile(userdata.user)
      setProfile(values => ({ ...values, auth_type: 'email' }))
      if (userdata.user.emailVerified) {
        checkUserExist(
          userdata.user.uid,
          response => {
            let firebase_id = userdata.user.uid
            let phone = null
            let image_url = userdata.user.photoURL
            let name = null
            let fcm_id = null
            let friends_code = null
            register(
              firebase_id,
              'email',
              name,
              email,
              image_url,
              phone,
              fcm_id,
              friends_code,
              success => {
                setNewUserScreen(false)
                toast.success(t('successfully_login'))
                if (response.message === '131') {
                  //If new User then show the Update Profile Screen
                  setNewUserScreen(true)
                } else {
                  router.push('/quiz-play')
                }
              },
              error => {
                if (error === '126') {
                  toast.error(t('ac_deactive'))
                } else {
                  toast.error(`${t('please ')}${t('try_again')}`)
                  console.log('signin handleSignin', error)
                }
              }
            )
            setLoading(false)
          },
          error => {
            console.log('onerror', error)
          }
        )
      } else {
        toast.error(t('ver_email_first'))
        setLoading(false)
      }
    } catch (error) {
      handleFirebaseAuthError(error.code)
      setLoading(false)
    }
  }

  //google sign in
  const signInWithGoogle = async e => {
    e.preventDefault()
    const provider = new GoogleAuthProvider()
    try {
      const response = await signInWithPopup(auth, provider)
      const { user } = response

      setProfile(user)
      setProfile(values => ({
        ...values,
        auth_type: 'gmail'
      }))

      const { uid: firebase_id, email, phoneNumber: phone, photoURL: image_url } = user
      const name = null
      const fcm_id = null
      const friends_code = null
      const { isNewUser } = getAdditionalUserInfo(response)
      register(
        firebase_id,
        'gmail',
        name,
        email,
        image_url,
        phone,
        fcm_id,
        friends_code,
        success => {
          setLoading(false)
          toast.success(t('successfully_login'))

          if (isNewUser) {
            setNewUserScreen(true) // If new User, show the Update Profile Screen
          } else {
            router.push('/quiz-play')
          }
        },
        error => {
          if (error === '126') {
            toast.error(t('ac_deactive'))
          } else {
            toast.error(`${t('please ')}${t('try_again')}`)
            console.log('logIn signInWithGoogle', error)
          }
        }
      )
    } catch (error) {
      handleFirebaseAuthError(error.code)
      setLoading(false)
    }
  }

  // show password
  const handletoggle = () => {
    if (type === 'password') {
      setIcon(<BsEye />)
      setType('text')
    } else {
      setIcon(<BsEyeSlash />)
      setType('password')
    }
  }
  useEffect(() => {
    setTimeout(() => {
      emailRef.current?.focus()
    }, 100)
  }, [])
  return (
    <Layout>
      <div className=' relative m-auto flex justify-center items-center pb-[150px] max-991:h-auto mt-5'>
        { !newUserScreen ? (
          <div className='max-w-[600px] px-[15px] mx-auto w-full '>
            <div className='row rounded-lg border-2 border-white bg-white bg-opacity-6 relative'>
              <div className='w-full  border-solid relative'>
                <div className='  p-11 max-767:px-3 bg-[#F0F0F2] rounded-xl'>
                  <h3 className='headline'>
                    {t('login')}
                  </h3>

                  <div className='my-[30px] mx-auto'>
                    <ul className='flex  items-center justify-between gap-5 cursor-pointer pl-0 max-575:flex-col'>
                      {systemconfig.gmail_login === '1' && (
                        <li className='flex items-center w-full'>
                          <button
                            className=' flex gap-3 w-full font-medium text-black py-4 px-5 justify-center items-center rounded-[16px] border border-[rgba(9,0,41,0.48)] '
                            onClick={signInWithGoogle}
                          >
                            <FcGoogle /> {t('login_with_google')}
                          </button>
                        </li>
                      )}
                      {systemconfig.phone_login === '1' && (
                        <li className='flex items-center w-full'>
                          <button
                            className=' flex gap-3 w-full font-medium text-black py-4 px-7 justify-center items-center rounded-[16px] border border-[rgba(9,0,41,0.48)]'
                            onClick={() => {
                              router.push('/auth/otp-verify')
                            }}
                          >
                            <FaMobileAlt /> {t('login_phone')}
                          </button>
                        </li>
                      )}
                    </ul>
                  </div>

                  {(systemconfig.phone_login === '1' || systemconfig.gmail_login === '1') &&
                    systemconfig.email_login === '1' && (
                      <div className=' mb-5 flex justify-center items-center'>
                        <span className='h-px w-[20%] opacity-15 bg-black max-575:hidden'></span>
                        <p className='mx-5'>{t('or_continue_with_email')}</p>
                        <span className='h-px w-[20%] opacity-15 bg-black max-575:hidden '></span>
                      </div>
                    )}

                  {systemconfig.email_login === '1' && (
                    <form onSubmit={e => handleSignin(e)} >
                      {/* Email Input */}
                      <div className='relative inline-block w-full'>
                        <Input
                          id='email'
                          type='email'
                          placeholder={t('enter_email')}
                          className='w-full mb-5 rounded-[8px] bg-white h-16 rtl:pr-14 ltr:pl-14 text-[#212529] border border-gray-300'
                          ref={emailRef}
                          required
                        />
                        <span className='absolute top-0 rtl:right-0 ltr:left-0 w-12 h-16 flex justify-center items-center text-[#ddd]'>
                          <HiOutlineMail />
                        </span>
                      </div>

                      {/* Password Input */}
                      <div className='relative inline-block w-full'>
                        <Input
                          id='password'
                          type={type}
                          placeholder={t('enter_password')}
                          className='w-full rounded-[8px] bg-white h-16 rtl:pr-14 ltr:pl-14 text-[#212529] border border-gray-300'
                          ref={passwordRef}
                          required
                        />
                        <span className='absolute top-0 rtl:right-0 ltr:left-0 w-12 h-16 flex justify-center items-center text-[#ddd]'>
                          <FaLock />
                        </span>
                        <span
                          onClick={handletoggle}
                          className='absolute top-6 rtl:left-4 ltr:right-4 flex justify-center items-center cursor-pointer text-[#141313]'
                        >
                          {Icon}
                        </span>
                      </div>

                      {/* Forgot Password Link */}
                      <div className='text-right my-5'>
                        <small>
                          <Link href='/auth/reset-password' className='text-sm text-black font-semibold '>
                            {t('forgot_pass')}?
                          </Link>
                        </small>
                      </div>

                      {/* Submit Button */}
                      <Button
                        type='submit'
                        variant='login'
                        size='login'
                        className=' '
                        disabled={loading}
                      >
                        {loading ? t('please_wait') : t('login')}
                      </Button>
                    </form>
                  )}
                  {(systemconfig.email_login === '0' &&
                    systemconfig.gmail_login === '0' &&
                    systemconfig.phone_login === '1') ||
                  (systemconfig.email_login === '0' &&
                    systemconfig.gmail_login === '1' &&
                    systemconfig.phone_login === '0') ? (
                    ''
                  ) : (
                    <p className='text-center'>
                      {t('dont_have_acc')}&nbsp;
                      <span>
                        <Link href='/auth/sign-up' replace className='text-gray-800 font-semibold'>
                          {t('sign_up')}
                        </Link>
                      </span>
                    </p>
                  )}
                </div>
              </div>
            </div>
          </div>
        ) : (
          <NewUser profile={profile} setProfile={setProfile} />
        )}
      </div>
    </Layout>
  )
}

export default withTranslation()(Login)
