'use client'
import React, { useEffect, useRef, useState } from 'react'
import { FaMobileAlt, FaLock } from 'react-icons/fa'
import { FcGoogle } from 'react-icons/fc'
import toast from 'react-hot-toast'
import { withTranslation } from 'react-i18next'
import { register } from '@/store/reducers/userSlice'
import FirebaseData from '@/utils/Firebase'
import 'swiper/css/effect-fade'
import 'swiper/css'
import 'swiper/css/navigation'
import 'swiper/css/pagination'
import Link from 'next/link'
import { useRouter } from 'next/navigation'
import { BsEyeSlash, BsEye } from 'react-icons/bs'
import NewUser from '@/components/Common/NewUser'
import dynamic from 'next/dynamic'
import { t } from '@/utils'
import {
  GoogleAuthProvider,
  createUserWithEmailAndPassword,
  getAdditionalUserInfo,
  sendEmailVerification,
  signInWithPopup
} from 'firebase/auth'
import { handleFirebaseAuthError } from '@/utils'
import { sysConfigdata } from '@/store/reducers/settingsSlice'
import { useSelector } from 'react-redux'
import { HiOutlineMail } from 'react-icons/hi'
import { Form, FormField, FormItem, FormLabel, FormControl } from '@/components/ui/form'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
const Layout = dynamic(() => import('@/components/Layout/Layout'), { ssr: false })

const SignUp = () => {
  const [loading, setLoading] = useState(false)
  const [newUserScreen, setNewUserScreen] = useState(false)
  const [profile, setProfile] = useState({
    name: '',
    mobile: '',
    email: '',
    profile: '',
    all_time_rank: '',
    all_time_score: '',
    coins: '',
    friends_code: ''
  })

  const [type, setType] = useState('password')

  const [type2, setType2] = useState('password')

  const [Icon, setIcon] = useState(<BsEyeSlash />)

  const [Icon2, setIcon2] = useState(<BsEyeSlash />)

  const [confPassword, setConfPassword] = useState('')

  const emailRef = useRef()

  const passwordRef = useRef()

  const router = useRouter()

  const { auth } = FirebaseData()

  const systemconfig = useSelector(sysConfigdata)
  //signup
  const signup = async (email, password) => {
    let promise = await new Promise(function (resolve, reject) {
      createUserWithEmailAndPassword(auth, email, password)
        .then(userCredential => {
          let resposne = userCredential.user
          sendEmailVerification(resposne)
          toast.success(t('email_sent'))
          resolve(userCredential)
          auth.signOut()
        })
        .catch(error => reject(error))
    })
    return promise
  }

  //email signin
  const handleSignup = e => {
    e.preventDefault()
    const email = emailRef.current.value
    const password = passwordRef.current.value
    if (password === confPassword) {
      setLoading(true)
      signup(email, password)
        .then(response => {
          setLoading(false)
          router.push('/')
        })
        .catch(err => {
          toast.error(err.message)
          setLoading(false)
        })
    } else {
      toast.error(t('password_mismatch_warning'))
    }
  }

  //google sign in
  const signInWithGoogle = async e => {
    e.preventDefault()
    const provider = new GoogleAuthProvider()
    try {
      const response = await signInWithPopup(auth, provider)
      const { user, additionalUserInfo } = response

      setProfile(user)
      setProfile(values => ({ ...values, auth_type: 'gmail' }))
      const { isNewUser } = getAdditionalUserInfo(response)
      if (isNewUser) {
        // If new User, show the Update Profile Screen
        setNewUserScreen(true)
      } else {
        const { uid: firebase_id, email, phoneNumber: phone, photoURL: image_url } = user
        const name = null
        const fcm_id = null
        const friends_code = null

        register(
          firebase_id,
          'gmail',
          name,
          email,
          image_url,
          phone,
          fcm_id,
          friends_code,
          () => {
            setLoading(false)
            toast.success(t('successfully_login'))
            router.push('/quiz-play')
          },
          () => {
            if (error === '126') {
              toast.error(t('ac_deactive'))
            } else {
              toast.error(`${t('please ')}${t('try_again')}`)
              console.log('signUp signInWithGoogle', error)
            }
          }
        )
      }

      setLoading(false)
    } catch (error) {
      handleFirebaseAuthError(error.code)
      setLoading(false)
    }
  }

  // show password
  const handletoggle = () => {
    if (type === 'password') {
      setIcon(<BsEye />)
      setType('text')
    } else {
      setIcon(<BsEyeSlash />)
      setType('password')
    }
  }
  // show confirm password
  const handletoggle2 = () => {
    if (type2 === 'password') {
      setIcon2(<BsEye />)
      setType2('text')
    } else {
      setIcon2(<BsEyeSlash />)
      setType2('password')
    }
  }
  useEffect(() => {
    setTimeout(() => {
      emailRef.current?.focus()
    }, 100)
  }, [])
  return (
    <Layout>
      <div className='container mt-5'>
        {!newUserScreen ? (
          <div className='max-w-[600px] w-full m-auto mt-5 mb-40'>
            <div className=' morphisam'>
              <div className='md:p-5 relative'>
                <h3 className='headline'>
                  {t('sign_up')}
                </h3>

                <div className='my-[30px] mx-auto'>
                  <ul className='flex  items-center justify-between gap-5 cursor-pointer pl-0 max-575:flex-col'>
                    {systemconfig.gmail_login === '1' && (
                      <li className='flex items-center w-full'>
                        <button
                          className='flex gap-3 w-full font-medium text-black py-4 px-3 sm:px-7 justify-center items-center rounded-[16px] border border-[rgba(9,0,41,0.48)] '
                          onClick={signInWithGoogle}
                        >
                          <FcGoogle /> {t('Login with Google')}
                        </button>
                      </li>
                    )}
                    {systemconfig.phone_login === '1' && (
                      <li className='flex items-center w-full'>
                        <button
                          className='flex gap-3 w-full font-medium text-black py-4 px-3 sm:px-7 justify-center items-center rounded-[16px] border border-[rgba(9,0,41,0.48)] '
                          onClick={() => {
                            router.push('/auth/otp-verify')
                          }}
                        >
                          <FaMobileAlt /> {t('Login with Phone')}
                        </button>
                      </li>
                    )}
                  </ul>
                </div>
                {(systemconfig.phone_login === '1' || systemconfig.gmail_login === '1') &&
                  systemconfig.email_login === '1' && (
                    <div className=' mb-5 flex justify-center items-center'>
                      <span className='h-px w-[20%] opacity-15 bg-black max-575:hidden'></span>
                      <p className='mx-2 sm:mx-5'>{t('or_continue_with_email')}</p>
                      <span className='h-px w-[20%] opacity-15 bg-black max-575:hidden '></span>
                    </div>
                  )}
                {systemconfig.email_login === '1' && (
                  <form onSubmit={e => handleSignup(e)}>
                    <div className='mb-3 relative inline-block w-full'>
                      <Input
                        type='email'
                        placeholder={t('enter_email')}
                        className='w-full rounded-[8px] bg-white h-16 pl-9 rtl:pr-10 sm:rtl:pr-14 ltr:sm:pl-14 text-[#212529] border border-gray-300'
                        required={true}
                        ref={emailRef}
                      />
                      <span className='absolute top-0 rtl:right-0 ltr:left-0 w-12 h-16 flex justify-center items-center text-[#ddd]'>
                        <HiOutlineMail />
                      </span>
                    </div>

                    <div className='mb-3 relative inline-block w-full'>
                      <Input
                        type={type}
                        placeholder={t('enter_password')}
                        className='w-full rounded-[8px] bg-white h-16 pl-9 rtl:pr-10 sm:rtl:pr-14 ltr:sm:pl-14 text-[#212529] border border-gray-300 placeholder:truncate'
                        required={true}
                        ref={passwordRef}
                      />
                      <span className='absolute top-0 rtl:right-0 ltr:left-0 w-12 h-16 flex justify-center items-center text-[#ddd]'>
                        <FaLock />
                      </span>
                      <span onClick={handletoggle} className='password_icon absolute top-1/3 ltr:right-2 rtl:left-2 rtl:sm:left-4 ltr:sm:right-4'>
                        {Icon}
                      </span>
                    </div>

                    <div className='mb-3 relative inline-block w-full'>
                      <Input
                        type={type2}
                        placeholder={t('confirm_password')}
                        className='w-full rounded-[8px] bg-white h-16 pl-9 rtl:pr-10 sm:rtl:pr-14 ltr:sm:pl-14 text-[#212529] border border-gray-300 placeholder:truncate'
                        required={true}
                        onChange={e => setConfPassword(e.target.value)}
                      />
                      <span className='absolute top-0 rtl:right-0 ltr:left-0 w-12 h-16 flex justify-center items-center text-[#ddd]'>
                        <FaLock />
                      </span>
                      <span onClick={handletoggle2} className='password_icon absolute top-1/3 ltr:right-2 rtl:left-2 rtl:sm:left-4 ltr:sm:right-4'>
                        {Icon2}
                      </span>
                    </div>

                    <div className='flex-center text-[#748494]'>
                      <small className='flex items-center text-center gap-2'>
                        <input type='checkbox' className='accent-black w-5 h-5' name='agree' id='agree' required />

                        {/* <u>
                          <Link className='conditions' href='/terms-conditions'>
                            {t('t&c')}
                          </Link>
                        </u>
                        &nbsp;&&nbsp;
                        <u>
                          <Link className='conditions' href='/privacy-policy'>
                            {t('privacy_policy')}
                          </Link>
                        </u> */}
                        <div>
                          {t('user_agreement_msg')}&nbsp;
                          <Link href={"/terms-conditions"} className='underline'>{t('t&c')}</Link>
                          &nbsp;&&nbsp;
                          <Link href={"/privacy-policy"} className='underline'>{t('privacy_policy')}</Link>
                        </div>
                      </small>
                    </div>

                    <Button variant='login' size='login' type='submit' disabled={loading}>
                      {loading ? t('please_wait') : `${t('create')} ${t('details')}`}
                    </Button>
                  </form>
                )}

                <p className='text-center'>
                  {t('already_have_acc')}
                  <span>
                    <Link href={'/auth/login'} replace className='text-black font-semibold'>
                      &nbsp;{t('login')}
                    </Link>
                  </span>
                </p>
              </div>
            </div>
          </div>
        ) : (
          <NewUser profile={profile} setProfile={setProfile} />
        )}
      </div>
    </Layout>
  )
}
export default withTranslation()(SignUp)
