'use client'
import React, { useEffect, useState } from 'react'
import { getClientTimeZone, getClientTimeZoneGMTFormat, t } from '@/utils'
import { ContestPlayApi, UserCoinScoreApi } from '@/store/actions/campaign'
import { LoadcontestLeaderboard, Loadtempdata, reviewAnswerShowSuccess } from '@/store/reducers/tempDataSlice'
import { useRouter } from 'next/navigation'
import Breadcrumb from '@/components/Common/Breadcrumb'
import { selectCurrentLanguage } from '@/store/reducers/languageSlice'
import Past from '@/components/Quiz/ContestPlay/Past'
import Live from '@/components/Quiz/ContestPlay/Live'
import Upcoming from '@/components/Quiz/ContestPlay/Upcoming'
import { updateUserDataInfo } from '@/store/reducers/userSlice'
import { useDispatch, useSelector } from 'react-redux'
import toast from 'react-hot-toast'
import dynamic from 'next/dynamic'
import { Tabs, TabsList, TabsTrigger, TabsContent } from '@/components/ui/tabs'

const Layout = dynamic(() => import('@/components/Layout/Layout'), { ssr: false })

const ContestPlay = () => {
  const dispatch = useDispatch()
  //states
  const [livecontest, setLiveContest] = useState()

  const [pastcontest, setPastContest] = useState()

  const [upcoming, setUpComing] = useState()

  const navigate = useRouter()

  // store data get
  const userData = useSelector(state => state.User)

  const timezone = getClientTimeZone();
  const gmt_format = getClientTimeZoneGMTFormat();

  const AllData = () => {
    ContestPlayApi({
      timezone,
      gmt_format,
      onSuccess: response => {
        let liveData = response.live_contest.data
        setLiveContest(liveData)

        let pastData = response.past_contest.data
        setPastContest(pastData)

        let upcomingData = response.upcoming_contest.data
        setUpComing(upcomingData)
      },
      onError: error => {
        console.log(error)
      }
    })
  }

  //live play btn
  const playBtn = (contestid, entrycoin) => {
    if (Number(entrycoin) > Number(userData?.data?.coins)) {
      toast.error(t('no_enough_coins'))
      return false
    }
    navigate.push({ pathname: '/contest-play/contest-play-board' })
    let data = { contest_id: contestid, entry_coin: entrycoin }
    Loadtempdata(data)
    UserCoinScoreApi({
      coins: '-' + entrycoin,
      title: t('contest_entry_point'),
      status: '1',
      onSuccess: response => {
        updateUserDataInfo(response.data)
      },
      onError: error => {
        console.log(error)
      }
    })
  }

  //past leaderboard btn
  const LeaderBoard = contest_id => {
    navigate.push({ pathname: '/contest-play/contest-leaderboard' })
    let data = { past_id: contest_id }
    LoadcontestLeaderboard(data)
  }

  useEffect(() => {
    AllData()
    dispatch(reviewAnswerShowSuccess(false))
  }, [selectCurrentLanguage])

  return (
    <Layout>
      <Breadcrumb
        showBreadcrumb={true}
        title={t('Contest Play')}
        content={t('home')}
        allgames={`${t('quiz')} ${t('play')}`}
        contentTwo=''
      />
      <div className='container mt-5 my-10'>
        <Tabs defaultValue='live' className='w-full '>
          <TabsList className='flex flex-wrap h-full'>
            <TabsTrigger value='past' className='w-1/3 max-479:w-1/2 data-[state=active]:text-white data-[state=active]:bg-primary-color data-[state=active]:outline-none capitalize p-2 text-base sm:p-3 md:text-lg font-bold  border-none outline-none  rounded-[8px] bg-[#F0F0F2]'>{t('finished')}</TabsTrigger>
            <TabsTrigger value='live' className='w-1/3 max-479:w-1/2 data-[state=active]:text-white data-[state=active]:bg-primary-color data-[state=active]:outline-none capitalize p-2 text-base sm:p-3 md:text-lg font-bold  border-none outline-none  rounded-[8px] bg-[#F0F0F2]'>{t('ongoing')}</TabsTrigger>
            <TabsTrigger value='upcoming' className='w-1/3 max-479:w-full max-479:solid max-479:border-t  max-479:border-gray-300 data-[state=active]:text-white data-[state=active]:bg-primary-color data-[state=active]:outline-none capitalize p-2 text-base sm:p-3 md:text-lg font-bold outline-none  rounded-[8px] bg-[#F0F0F2]'>{t('upcoming')}</TabsTrigger>
          </TabsList>

          <TabsContent value='past'>
            <Past data={pastcontest} LeaderBoard={LeaderBoard} />
          </TabsContent>

          <TabsContent value='live'>
            <Live data={livecontest} playBtn={playBtn} />
          </TabsContent>

          <TabsContent value='upcoming'>
            <Upcoming data={upcoming} />
          </TabsContent>
        </Tabs>
      </div>
    </Layout>
  )
}

export default ContestPlay
