'use client'
import { lazy, Suspense, useEffect, useState } from 'react'
import Breadcrumb from '@/components/Common/Breadcrumb'
import { withTranslation } from 'react-i18next'
import { useDispatch, useSelector } from 'react-redux'
import { sysConfigdata } from '@/store/reducers/settingsSlice'
import { dailyQuizApi, getusercoinsApi, setBadgesApi, UserCoinScoreApi } from '@/store/actions/campaign'
import { updateUserDataInfo } from '@/store/reducers/userSlice'
import { badgesData, LoadNewBadgesData } from '@/store/reducers/badgesSlice'
import toast from 'react-hot-toast'
import dynamic from 'next/dynamic'
import { reviewAnswerShowSuccess } from '@/store/reducers/tempDataSlice'
import { useRouter } from 'next/router'
import QuestionSkeleton from '@/components/view/common/QuestionSkeleton'
import { getClientTimeZone, getClientTimeZoneGMTFormat, t } from '@/utils'

const Layout = dynamic(() => import('@/components/Layout/Layout'), { ssr: false })
const DailyQuizQuestions = lazy(() => import('@/components/Quiz/DailyQuiz/DailyQuizQuestions'))
const DailyQuizDashboard = () => {
  const [questions, setQuestions] = useState([{ id: '', isBookmarked: false }])

  const systemconfig = useSelector(sysConfigdata)

  const dispatch = useDispatch()

  const navigate = useRouter()

  const Badges = useSelector(badgesData)

  const thirstyBadge = Badges?.data?.find(badge => badge?.type === 'thirsty')

  const thirsty_status = thirstyBadge && thirstyBadge?.status

  const thirsty_coin = thirstyBadge && thirstyBadge?.badge_reward

  let timerseconds = parseInt(systemconfig.quiz_zone_duration)

  const TIMER_SECONDS = timerseconds

  const timezone = getClientTimeZone();
  const gmt_format = getClientTimeZoneGMTFormat();

  useEffect(() => {
    getNewQuestions()
    dispatch(reviewAnswerShowSuccess(false))
  }, [])

  const getNewQuestions = () => {
    dailyQuizApi({
      timezone,
      gmt_format,
      onSuccess: response => {
        if (response.data && !response.data.error) {
          let questions = response.data.map(data => {
            let question = data?.question

            let note = data?.note

            return {
              ...data,
              note: note,
              question: question,
              selected_answer: '',
              isAnswered: false
            }
          })
          setQuestions(questions)
        }
      },
      onError: error => {
        if (error === '112') {
          toast.error(t('already_played'))
          navigate.push('/quiz-play')
          return false
        }

        if (error === '102') {
          toast.error(t('no_que_found'))
          navigate.push('/quiz-play')

          return false
        }
      }
    })
  }

  const handleAnswerOptionClick = questions => {
    setQuestions(questions)
  }

  useEffect(() => {
    if (thirsty_status === '0') {
      setBadgesApi(
        'thirsty',
        res => {
          LoadNewBadgesData('thirsty', '1')
          toast.success(t(res?.data?.notification_body))
          const status = 0
          UserCoinScoreApi({
            coins: thirsty_coin,
            title: t('thirsty_badge_reward'),
            status: status,
            onSuccess: response => {
              getusercoinsApi({
                onSuccess: responseData => {
                  updateUserDataInfo(responseData.data)
                },
                onError: error => {
                  console.log(error)
                }
              })
            },
            onError: error => {
              console.log(error)
            }
          })
        },
        error => {
          console.log(error)
        }
      )
    }
  }, [])

  return (
    <Layout>
      <Breadcrumb title={`${t('daily')} ${t('quiz')}`} content='' contentTwo='' />
      <div className='dashboard'>
        <div className='container mb-14'>
          {(() => {
            if (questions && questions?.length >= 0) {
              return (
                <Suspense fallback={<QuestionSkeleton />}>
                  <DailyQuizQuestions
                    questions={questions}
                    timerSeconds={TIMER_SECONDS}
                    onOptionClick={handleAnswerOptionClick}
                    showQuestions={true}
                    showLifeLine={true}
                  />
                </Suspense>
              )
            } else {
              return (
                <div className='text-center text-white'>
                  <p>{t('no_que_found')}</p>
                </div>
              )
            }
          })()}
        </div>
      </div>
    </Layout>
  )
}

export default withTranslation()(DailyQuizDashboard)
